import IRESTClientBuilder from "./IRESTClientBuilder";
import ClientResponse from "./ClientResponse";
export declare class FusionAuthClient {
    apiKey: string;
    host: string;
    tenantId?: string;
    clientBuilder: IRESTClientBuilder;
    constructor(apiKey: string, host: string, tenantId?: string);
    /**
     * Sets the tenant id, that will be included in the X-FusionAuth-TenantId header.
     *
     * @param {string | null} tenantId The value of the X-FusionAuth-TenantId header.
     * @returns {FusionAuthClient}
     */
    setTenantId(tenantId: string | null): this;
    /**
     * Takes an action on a user. The user being actioned is called the "actionee" and the user taking the action is called the
     * "actioner". Both user ids are required. You pass the actionee's user id into the method and the actioner's is put into the
     * request object.
     *
     * @param {string} actioneeUserId The actionee's user id.
     * @param {ActionRequest} request The action request that includes all of the information about the action being taken including
     *    the id of the action, any options and the duration (if applicable).
     * @returns {Promise<ClientResponse<ActionResponse>>}
     */
    actionUser(actioneeUserId: string, request: ActionRequest): Promise<ClientResponse<ActionResponse>>;
    /**
     * Adds a user to an existing family. The family id must be specified.
     *
     * @param {string} familyId The id of the family.
     * @param {FamilyRequest} request The request object that contains all of the information used to determine which user to add to the family.
     * @returns {Promise<ClientResponse<FamilyResponse>>}
     */
    addUserToFamily(familyId: string, request: FamilyRequest): Promise<ClientResponse<FamilyResponse>>;
    /**
     * Cancels the user action.
     *
     * @param {string} actionId The action id of the action to cancel.
     * @param {ActionRequest} request The action request that contains the information about the cancellation.
     * @returns {Promise<ClientResponse<ActionResponse>>}
     */
    cancelAction(actionId: string, request: ActionRequest): Promise<ClientResponse<ActionResponse>>;
    /**
     * Changes a user's password using the change password Id. This usually occurs after an email has been sent to the user
     * and they clicked on a link to reset their password.
     *
     * @param {string} changePasswordId The change password Id used to find the user. This value is generated by FusionAuth once the change password workflow has been initiated.
     * @param {ChangePasswordRequest} request The change password request that contains all of the information used to change the password.
     * @returns {Promise<ClientResponse<ChangePasswordResponse>>}
     */
    changePassword(changePasswordId: string, request: ChangePasswordRequest): Promise<ClientResponse<ChangePasswordResponse>>;
    /**
     * Changes a user's password using their identity (login id and password). Using a loginId instead of the changePasswordId
     * bypasses the email verification and allows a password to be changed directly without first calling the #forgotPassword
     * method.
     *
     * @param {ChangePasswordRequest} request The change password request that contains all of the information used to change the password.
     * @returns {Promise<ClientResponse<void>>}
     */
    changePasswordByIdentity(request: ChangePasswordRequest): Promise<ClientResponse<void>>;
    /**
     * Adds a comment to the user's account.
     *
     * @param {UserCommentRequest} request The request object that contains all of the information used to create the user comment.
     * @returns {Promise<ClientResponse<void>>}
     */
    commentOnUser(request: UserCommentRequest): Promise<ClientResponse<void>>;
    /**
     * Creates an application. You can optionally specify an Id for the application, if not provided one will be generated.
     *
     * @param {string} applicationId (Optional) The Id to use for the application. If not provided a secure random UUID will be generated.
     * @param {ApplicationRequest} request The request object that contains all of the information used to create the application.
     * @returns {Promise<ClientResponse<ApplicationResponse>>}
     */
    createApplication(applicationId: string, request: ApplicationRequest): Promise<ClientResponse<ApplicationResponse>>;
    /**
     * Creates a new role for an application. You must specify the id of the application you are creating the role for.
     * You can optionally specify an Id for the role inside the ApplicationRole object itself, if not provided one will be generated.
     *
     * @param {string} applicationId The Id of the application to create the role on.
     * @param {string} roleId (Optional) The Id of the role. If not provided a secure random UUID will be generated.
     * @param {ApplicationRequest} request The request object that contains all of the information used to create the application role.
     * @returns {Promise<ClientResponse<ApplicationResponse>>}
     */
    createApplicationRole(applicationId: string, roleId: string, request: ApplicationRequest): Promise<ClientResponse<ApplicationResponse>>;
    /**
     * Creates an audit log with the message and user name (usually an email). Audit logs should be written anytime you
     * make changes to the FusionAuth database. When using the FusionAuth App web interface, any changes are automatically
     * written to the audit log. However, if you are accessing the API, you must write the audit logs yourself.
     *
     * @param {AuditLogRequest} request The request object that contains all of the information used to create the audit log entry.
     * @returns {Promise<ClientResponse<AuditLogResponse>>}
     */
    createAuditLog(request: AuditLogRequest): Promise<ClientResponse<AuditLogResponse>>;
    /**
     * Creates a user consent type. You can optionally specify an Id for the consent type, if not provided one will be generated.
     *
     * @param {string} consentId (Optional) The Id for the consent. If not provided a secure random UUID will be generated.
     * @param {ConsentRequest} request The request object that contains all of the information used to create the consent.
     * @returns {Promise<ClientResponse<ConsentResponse>>}
     */
    createConsent(consentId: string, request: ConsentRequest): Promise<ClientResponse<ConsentResponse>>;
    /**
     * Creates an email template. You can optionally specify an Id for the template, if not provided one will be generated.
     *
     * @param {string} emailTemplateId (Optional) The Id for the template. If not provided a secure random UUID will be generated.
     * @param {EmailTemplateRequest} request The request object that contains all of the information used to create the email template.
     * @returns {Promise<ClientResponse<EmailTemplateResponse>>}
     */
    createEmailTemplate(emailTemplateId: string, request: EmailTemplateRequest): Promise<ClientResponse<EmailTemplateResponse>>;
    /**
     * Creates a family with the user id in the request as the owner and sole member of the family. You can optionally specify an id for the
     * family, if not provided one will be generated.
     *
     * @param {string} familyId (Optional) The id for the family. If not provided a secure random UUID will be generated.
     * @param {FamilyRequest} request The request object that contains all of the information used to create the family.
     * @returns {Promise<ClientResponse<FamilyResponse>>}
     */
    createFamily(familyId: string, request: FamilyRequest): Promise<ClientResponse<FamilyResponse>>;
    /**
     * Creates a group. You can optionally specify an Id for the group, if not provided one will be generated.
     *
     * @param {string} groupId (Optional) The Id for the group. If not provided a secure random UUID will be generated.
     * @param {GroupRequest} request The request object that contains all of the information used to create the group.
     * @returns {Promise<ClientResponse<GroupResponse>>}
     */
    createGroup(groupId: string, request: GroupRequest): Promise<ClientResponse<GroupResponse>>;
    /**
     * Creates a member in a group.
     *
     * @param {MemberRequest} request The request object that contains all of the information used to create the group member(s).
     * @returns {Promise<ClientResponse<MemberResponse>>}
     */
    createGroupMembers(request: MemberRequest): Promise<ClientResponse<MemberResponse>>;
    /**
     * Creates an identity provider. You can optionally specify an Id for the identity provider, if not provided one will be generated.
     *
     * @param {string} identityProviderId (Optional) The Id of the identity provider. If not provided a secure random UUID will be generated.
     * @param {IdentityProviderRequest} request The request object that contains all of the information used to create the identity provider.
     * @returns {Promise<ClientResponse<IdentityProviderResponse>>}
     */
    createIdentityProvider(identityProviderId: string, request: IdentityProviderRequest): Promise<ClientResponse<IdentityProviderResponse>>;
    /**
     * Creates a Lambda. You can optionally specify an Id for the lambda, if not provided one will be generated.
     *
     * @param {string} lambdaId (Optional) The Id for the lambda. If not provided a secure random UUID will be generated.
     * @param {LambdaRequest} request The request object that contains all of the information used to create the lambda.
     * @returns {Promise<ClientResponse<LambdaResponse>>}
     */
    createLambda(lambdaId: string, request: LambdaRequest): Promise<ClientResponse<LambdaResponse>>;
    /**
     * Creates a tenant. You can optionally specify an Id for the tenant, if not provided one will be generated.
     *
     * @param {string} tenantId (Optional) The Id for the tenant. If not provided a secure random UUID will be generated.
     * @param {TenantRequest} request The request object that contains all of the information used to create the tenant.
     * @returns {Promise<ClientResponse<TenantResponse>>}
     */
    createTenant(tenantId: string, request: TenantRequest): Promise<ClientResponse<TenantResponse>>;
    /**
     * Creates a Theme. You can optionally specify an Id for the theme, if not provided one will be generated.
     *
     * @param {string} themeId (Optional) The Id for the theme. If not provided a secure random UUID will be generated.
     * @param {ThemeRequest} request The request object that contains all of the information used to create the theme.
     * @returns {Promise<ClientResponse<ThemeResponse>>}
     */
    createTheme(themeId: string, request: ThemeRequest): Promise<ClientResponse<ThemeResponse>>;
    /**
     * Creates a user. You can optionally specify an Id for the user, if not provided one will be generated.
     *
     * @param {string} userId (Optional) The Id for the user. If not provided a secure random UUID will be generated.
     * @param {UserRequest} request The request object that contains all of the information used to create the user.
     * @returns {Promise<ClientResponse<UserResponse>>}
     */
    createUser(userId: string, request: UserRequest): Promise<ClientResponse<UserResponse>>;
    /**
     * Creates a user action. This action cannot be taken on a user until this call successfully returns. Anytime after
     * that the user action can be applied to any user.
     *
     * @param {string} userActionId (Optional) The Id for the user action. If not provided a secure random UUID will be generated.
     * @param {UserActionRequest} request The request object that contains all of the information used to create the user action.
     * @returns {Promise<ClientResponse<UserActionResponse>>}
     */
    createUserAction(userActionId: string, request: UserActionRequest): Promise<ClientResponse<UserActionResponse>>;
    /**
     * Creates a user reason. This user action reason cannot be used when actioning a user until this call completes
     * successfully. Anytime after that the user action reason can be used.
     *
     * @param {string} userActionReasonId (Optional) The Id for the user action reason. If not provided a secure random UUID will be generated.
     * @param {UserActionReasonRequest} request The request object that contains all of the information used to create the user action reason.
     * @returns {Promise<ClientResponse<UserActionReasonResponse>>}
     */
    createUserActionReason(userActionReasonId: string, request: UserActionReasonRequest): Promise<ClientResponse<UserActionReasonResponse>>;
    /**
     * Creates a single User consent.
     *
     * @param {string} userConsentId (Optional) The Id for the User consent. If not provided a secure random UUID will be generated.
     * @param {UserConsentRequest} request The request that contains the user consent information.
     * @returns {Promise<ClientResponse<UserConsentResponse>>}
     */
    createUserConsent(userConsentId: string, request: UserConsentRequest): Promise<ClientResponse<UserConsentResponse>>;
    /**
     * Creates a webhook. You can optionally specify an Id for the webhook, if not provided one will be generated.
     *
     * @param {string} webhookId (Optional) The Id for the webhook. If not provided a secure random UUID will be generated.
     * @param {WebhookRequest} request The request object that contains all of the information used to create the webhook.
     * @returns {Promise<ClientResponse<WebhookResponse>>}
     */
    createWebhook(webhookId: string, request: WebhookRequest): Promise<ClientResponse<WebhookResponse>>;
    /**
     * Deactivates the application with the given Id.
     *
     * @param {string} applicationId The Id of the application to deactivate.
     * @returns {Promise<ClientResponse<void>>}
     */
    deactivateApplication(applicationId: string): Promise<ClientResponse<void>>;
    /**
     * Deactivates the user with the given Id.
     *
     * @param {string} userId The Id of the user to deactivate.
     * @returns {Promise<ClientResponse<void>>}
     */
    deactivateUser(userId: string): Promise<ClientResponse<void>>;
    /**
     * Deactivates the user action with the given Id.
     *
     * @param {string} userActionId The Id of the user action to deactivate.
     * @returns {Promise<ClientResponse<void>>}
     */
    deactivateUserAction(userActionId: string): Promise<ClientResponse<void>>;
    /**
     * Deactivates the users with the given ids.
     *
     * @param {Array<string>} userIds The ids of the users to deactivate.
     * @returns {Promise<ClientResponse<void>>}
     */
    deactivateUsers(userIds: Array<string>): Promise<ClientResponse<void>>;
    /**
     * Hard deletes an application. This is a dangerous operation and should not be used in most circumstances. This will
     * delete the application, any registrations for that application, metrics and reports for the application, all the
     * roles for the application, and any other data associated with the application. This operation could take a very
     * long time, depending on the amount of data in your database.
     *
     * @param {string} applicationId The Id of the application to delete.
     * @returns {Promise<ClientResponse<void>>}
     */
    deleteApplication(applicationId: string): Promise<ClientResponse<void>>;
    /**
     * Hard deletes an application role. This is a dangerous operation and should not be used in most circumstances. This
     * permanently removes the given role from all users that had it.
     *
     * @param {string} applicationId The Id of the application to deactivate.
     * @param {string} roleId The Id of the role to delete.
     * @returns {Promise<ClientResponse<void>>}
     */
    deleteApplicationRole(applicationId: string, roleId: string): Promise<ClientResponse<void>>;
    /**
     * Deletes the consent for the given Id.
     *
     * @param {string} consentId The Id of the consent to delete.
     * @returns {Promise<ClientResponse<void>>}
     */
    deleteConsent(consentId: string): Promise<ClientResponse<void>>;
    /**
     * Deletes the email template for the given Id.
     *
     * @param {string} emailTemplateId The Id of the email template to delete.
     * @returns {Promise<ClientResponse<void>>}
     */
    deleteEmailTemplate(emailTemplateId: string): Promise<ClientResponse<void>>;
    /**
     * Deletes the group for the given Id.
     *
     * @param {string} groupId The Id of the group to delete.
     * @returns {Promise<ClientResponse<void>>}
     */
    deleteGroup(groupId: string): Promise<ClientResponse<void>>;
    /**
     * Removes users as members of a group.
     *
     * @param {MemberDeleteRequest} request The member request that contains all of the information used to remove members to the group.
     * @returns {Promise<ClientResponse<void>>}
     */
    deleteGroupMembers(request: MemberDeleteRequest): Promise<ClientResponse<void>>;
    /**
     * Deletes the identity provider for the given Id.
     *
     * @param {string} identityProviderId The Id of the identity provider to delete.
     * @returns {Promise<ClientResponse<void>>}
     */
    deleteIdentityProvider(identityProviderId: string): Promise<ClientResponse<void>>;
    /**
     * Deletes the key for the given Id.
     *
     * @param {string} keyOd The Id of the key to delete.
     * @returns {Promise<ClientResponse<void>>}
     */
    deleteKey(keyOd: string): Promise<ClientResponse<void>>;
    /**
     * Deletes the lambda for the given Id.
     *
     * @param {string} lambdaId The Id of the lambda to delete.
     * @returns {Promise<ClientResponse<void>>}
     */
    deleteLambda(lambdaId: string): Promise<ClientResponse<void>>;
    /**
     * Deletes the user registration for the given user and application.
     *
     * @param {string} userId The Id of the user whose registration is being deleted.
     * @param {string} applicationId The Id of the application to remove the registration for.
     * @returns {Promise<ClientResponse<void>>}
     */
    deleteRegistration(userId: string, applicationId: string): Promise<ClientResponse<void>>;
    /**
     * Deletes the tenant for the given Id.
     *
     * @param {string} tenantId The Id of the tenant to delete.
     * @returns {Promise<ClientResponse<void>>}
     */
    deleteTenant(tenantId: string): Promise<ClientResponse<void>>;
    /**
     * Deletes the theme for the given Id.
     *
     * @param {string} themeId The Id of the theme to delete.
     * @returns {Promise<ClientResponse<void>>}
     */
    deleteTheme(themeId: string): Promise<ClientResponse<void>>;
    /**
     * Deletes the user for the given Id. This permanently deletes all information, metrics, reports and data associated
     * with the user.
     *
     * @param {string} userId The Id of the user to delete.
     * @returns {Promise<ClientResponse<void>>}
     */
    deleteUser(userId: string): Promise<ClientResponse<void>>;
    /**
     * Deletes the user action for the given Id. This permanently deletes the user action and also any history and logs of
     * the action being applied to any users.
     *
     * @param {string} userActionId The Id of the user action to delete.
     * @returns {Promise<ClientResponse<void>>}
     */
    deleteUserAction(userActionId: string): Promise<ClientResponse<void>>;
    /**
     * Deletes the user action reason for the given Id.
     *
     * @param {string} userActionReasonId The Id of the user action reason to delete.
     * @returns {Promise<ClientResponse<void>>}
     */
    deleteUserActionReason(userActionReasonId: string): Promise<ClientResponse<void>>;
    /**
     * Deletes the users with the given ids.
     *
     * @param {UserDeleteRequest} request The ids of the users to delete.
     * @returns {Promise<ClientResponse<void>>}
     */
    deleteUsers(request: UserDeleteRequest): Promise<ClientResponse<void>>;
    /**
     * Deletes the webhook for the given Id.
     *
     * @param {string} webhookId The Id of the webhook to delete.
     * @returns {Promise<ClientResponse<void>>}
     */
    deleteWebhook(webhookId: string): Promise<ClientResponse<void>>;
    /**
     * Disable Two Factor authentication for a user.
     *
     * @param {string} userId The Id of the User for which you're disabling Two Factor authentication.
     * @param {string} code The Two Factor code used verify the the caller knows the Two Factor secret.
     * @returns {Promise<ClientResponse<void>>}
     */
    disableTwoFactor(userId: string, code: string): Promise<ClientResponse<void>>;
    /**
     * Enable Two Factor authentication for a user.
     *
     * @param {string} userId The Id of the user to enable Two Factor authentication.
     * @param {TwoFactorRequest} request The two factor enable request information.
     * @returns {Promise<ClientResponse<void>>}
     */
    enableTwoFactor(userId: string, request: TwoFactorRequest): Promise<ClientResponse<void>>;
    /**
     * Exchange a refresh token for a new JWT.
     *
     * @param {RefreshRequest} request The refresh request.
     * @returns {Promise<ClientResponse<RefreshResponse>>}
     */
    exchangeRefreshTokenForJWT(request: RefreshRequest): Promise<ClientResponse<RefreshResponse>>;
    /**
     * Begins the forgot password sequence, which kicks off an email to the user so that they can reset their password.
     *
     * @param {ForgotPasswordRequest} request The request that contains the information about the user so that they can be emailed.
     * @returns {Promise<ClientResponse<ForgotPasswordResponse>>}
     */
    forgotPassword(request: ForgotPasswordRequest): Promise<ClientResponse<ForgotPasswordResponse>>;
    /**
     * Generate a new Email Verification Id to be used with the Verify Email API. This API will not attempt to send an
     * email to the User. This API may be used to collect the verificationId for use with a third party system.
     *
     * @param {string} email The email address of the user that needs a new verification email.
     * @returns {Promise<ClientResponse<VerifyEmailResponse>>}
     */
    generateEmailVerificationId(email: string): Promise<ClientResponse<VerifyEmailResponse>>;
    /**
     * Generate a new RSA or EC key pair or an HMAC secret.
     *
     * @param {string} keyId (Optional) The Id for the key. If not provided a secure random UUID will be generated.
     * @param {KeyRequest} request The request object that contains all of the information used to create the key.
     * @returns {Promise<ClientResponse<KeyResponse>>}
     */
    generateKey(keyId: string, request: KeyRequest): Promise<ClientResponse<KeyResponse>>;
    /**
     * Generate a new Application Registration Verification Id to be used with the Verify Registration API. This API will not attempt to send an
     * email to the User. This API may be used to collect the verificationId for use with a third party system.
     *
     * @param {string} email The email address of the user that needs a new verification email.
     * @param {string} applicationId The Id of the application to be verified.
     * @returns {Promise<ClientResponse<VerifyRegistrationResponse>>}
     */
    generateRegistrationVerificationId(email: string, applicationId: string): Promise<ClientResponse<VerifyRegistrationResponse>>;
    /**
     * Generate a Two Factor secret that can be used to enable Two Factor authentication for a User. The response will contain
     * both the secret and a Base32 encoded form of the secret which can be shown to a User when using a 2 Step Authentication
     * application such as Google Authenticator.
     *
     * @returns {Promise<ClientResponse<SecretResponse>>}
     */
    generateTwoFactorSecret(): Promise<ClientResponse<SecretResponse>>;
    /**
     * Generate a Two Factor secret that can be used to enable Two Factor authentication for a User. The response will contain
     * both the secret and a Base32 encoded form of the secret which can be shown to a User when using a 2 Step Authentication
     * application such as Google Authenticator.
     *
     * @param {string} encodedJWT The encoded JWT (access token).
     * @returns {Promise<ClientResponse<SecretResponse>>}
     */
    generateTwoFactorSecretUsingJWT(encodedJWT: string): Promise<ClientResponse<SecretResponse>>;
    /**
     * Handles login via third-parties including Social login, external OAuth and OpenID Connect, and other
     * login systems.
     *
     * @param {IdentityProviderLoginRequest} request The third-party login request that contains information from the third-party login
     *    providers that FusionAuth uses to reconcile the user's account.
     * @returns {Promise<ClientResponse<LoginResponse>>}
     */
    identityProviderLogin(request: IdentityProviderLoginRequest): Promise<ClientResponse<LoginResponse>>;
    /**
     * Import an existing RSA or EC key pair or an HMAC secret.
     *
     * @param {string} keyId (Optional) The Id for the key. If not provided a secure random UUID will be generated.
     * @param {KeyRequest} request The request object that contains all of the information used to create the key.
     * @returns {Promise<ClientResponse<KeyResponse>>}
     */
    importKey(keyId: string, request: KeyRequest): Promise<ClientResponse<KeyResponse>>;
    /**
     * Bulk imports multiple users. This does some validation, but then tries to run batch inserts of users. This reduces
     * latency when inserting lots of users. Therefore, the error response might contain some information about failures,
     * but it will likely be pretty generic.
     *
     * @param {ImportRequest} request The request that contains all of the information about all of the users to import.
     * @returns {Promise<ClientResponse<void>>}
     */
    importUsers(request: ImportRequest): Promise<ClientResponse<void>>;
    /**
     * Issue a new access token (JWT) for the requested Application after ensuring the provided JWT is valid. A valid
     * access token is properly signed and not expired.
     * <p>
     * This API may be used in an SSO configuration to issue new tokens for another application after the user has
     * obtained a valid token from authentication.
     *
     * @param {string} applicationId The Application Id for which you are requesting a new access token be issued.
     * @param {string} encodedJWT The encoded JWT (access token).
     * @returns {Promise<ClientResponse<IssueResponse>>}
     */
    issueJWT(applicationId: string, encodedJWT: string): Promise<ClientResponse<IssueResponse>>;
    /**
     * Authenticates a user to FusionAuth.
     *
     * This API optionally requires an API key. See <code>Application.loginConfiguration.requireAuthentication</code>.
     *
     * @param {LoginRequest} request The login request that contains the user credentials used to log them in.
     * @returns {Promise<ClientResponse<LoginResponse>>}
     */
    login(request: LoginRequest): Promise<ClientResponse<LoginResponse>>;
    /**
     * Sends a ping to FusionAuth indicating that the user was automatically logged into an application. When using
     * FusionAuth's SSO or your own, you should call this if the user is already logged in centrally, but accesses an
     * application where they no longer have a session. This helps correctly track login counts, times and helps with
     * reporting.
     *
     * @param {string} userId The Id of the user that was logged in.
     * @param {string} applicationId The Id of the application that they logged into.
     * @param {string} callerIPAddress (Optional) The IP address of the end-user that is logging in. If a null value is provided
     *    the IP address will be that of the client or last proxy that sent the request.
     * @returns {Promise<ClientResponse<void>>}
     */
    loginPing(userId: string, applicationId: string, callerIPAddress: string): Promise<ClientResponse<void>>;
    /**
     * The Logout API is intended to be used to remove the refresh token and access token cookies if they exist on the
     * client and revoke the refresh token stored. This API does nothing if the request does not contain an access
     * token or refresh token cookies.
     *
     * @param {boolean} global When this value is set to true all of the refresh tokens issued to the owner of the
     *    provided token will be revoked.
     * @param {string} refreshToken (Optional) The refresh_token as a request parameter instead of coming in via a cookie.
     *    If provided this takes precedence over the cookie.
     * @returns {Promise<ClientResponse<void>>}
     */
    logout(global: boolean, refreshToken: string): Promise<ClientResponse<void>>;
    /**
     * Retrieves the identity provider for the given domain. A 200 response code indicates the domain is managed
     * by a registered identity provider. A 404 indicates the domain is not managed.
     *
     * @param {string} domain The domain or email address to lookup.
     * @returns {Promise<ClientResponse<LookupResponse>>}
     */
    lookupIdentityProvider(domain: string): Promise<ClientResponse<LookupResponse>>;
    /**
     * Modifies a temporal user action by changing the expiration of the action and optionally adding a comment to the
     * action.
     *
     * @param {string} actionId The Id of the action to modify. This is technically the user action log id.
     * @param {ActionRequest} request The request that contains all of the information about the modification.
     * @returns {Promise<ClientResponse<ActionResponse>>}
     */
    modifyAction(actionId: string, request: ActionRequest): Promise<ClientResponse<ActionResponse>>;
    /**
     * Complete a login request using a passwordless code
     *
     * @param {PasswordlessLoginRequest} request The passwordless login request that contains all of the information used to complete login.
     * @returns {Promise<ClientResponse<LoginResponse>>}
     */
    passwordlessLogin(request: PasswordlessLoginRequest): Promise<ClientResponse<LoginResponse>>;
    /**
     * Reactivates the application with the given Id.
     *
     * @param {string} applicationId The Id of the application to reactivate.
     * @returns {Promise<ClientResponse<ApplicationResponse>>}
     */
    reactivateApplication(applicationId: string): Promise<ClientResponse<ApplicationResponse>>;
    /**
     * Reactivates the user with the given Id.
     *
     * @param {string} userId The Id of the user to reactivate.
     * @returns {Promise<ClientResponse<UserResponse>>}
     */
    reactivateUser(userId: string): Promise<ClientResponse<UserResponse>>;
    /**
     * Reactivates the user action with the given Id.
     *
     * @param {string} userActionId The Id of the user action to reactivate.
     * @returns {Promise<ClientResponse<UserActionResponse>>}
     */
    reactivateUserAction(userActionId: string): Promise<ClientResponse<UserActionResponse>>;
    /**
     * Reconcile a User to FusionAuth using JWT issued from another Identity Provider.
     *
     * @param {IdentityProviderLoginRequest} request The reconcile request that contains the data to reconcile the User.
     * @returns {Promise<ClientResponse<LoginResponse>>}
     */
    reconcileJWT(request: IdentityProviderLoginRequest): Promise<ClientResponse<LoginResponse>>;
    /**
     * Request a refresh of the User search index. This API is not generally necessary and the search index will become consistent in a
     * reasonable amount of time. There may be scenarios where you may wish to manually request an index refresh. One example may be
     * if you are using the Search API or Delete Tenant API immediately following a User Create etc, you may wish to request a refresh to
     *  ensure the index immediately current before making a query request to the search index.
     *
     * @returns {Promise<ClientResponse<void>>}
     */
    refreshUserSearchIndex(): Promise<ClientResponse<void>>;
    /**
     * Registers a user for an application. If you provide the User and the UserRegistration object on this request, it
     * will create the user as well as register them for the application. This is called a Full Registration. However, if
     * you only provide the UserRegistration object, then the user must already exist and they will be registered for the
     * application. The user id can also be provided and it will either be used to look up an existing user or it will be
     * used for the newly created User.
     *
     * @param {string} userId (Optional) The Id of the user being registered for the application and optionally created.
     * @param {RegistrationRequest} request The request that optionally contains the User and must contain the UserRegistration.
     * @returns {Promise<ClientResponse<RegistrationResponse>>}
     */
    register(userId: string, request: RegistrationRequest): Promise<ClientResponse<RegistrationResponse>>;
    /**
     * Removes a user from the family with the given id.
     *
     * @param {string} familyId The id of the family to remove the user from.
     * @param {string} userId The id of the user to remove from the family.
     * @returns {Promise<ClientResponse<void>>}
     */
    removeUserFromFamily(familyId: string, userId: string): Promise<ClientResponse<void>>;
    /**
     * Re-sends the verification email to the user.
     *
     * @param {string} email The email address of the user that needs a new verification email.
     * @returns {Promise<ClientResponse<VerifyEmailResponse>>}
     */
    resendEmailVerification(email: string): Promise<ClientResponse<VerifyEmailResponse>>;
    /**
     * Re-sends the application registration verification email to the user.
     *
     * @param {string} email The email address of the user that needs a new verification email.
     * @param {string} applicationId The Id of the application to be verified.
     * @returns {Promise<ClientResponse<VerifyRegistrationResponse>>}
     */
    resendRegistrationVerification(email: string, applicationId: string): Promise<ClientResponse<VerifyRegistrationResponse>>;
    /**
     * Retrieves a single action log (the log of a user action that was taken on a user previously) for the given Id.
     *
     * @param {string} actionId The Id of the action to retrieve.
     * @returns {Promise<ClientResponse<ActionResponse>>}
     */
    retrieveAction(actionId: string): Promise<ClientResponse<ActionResponse>>;
    /**
     * Retrieves all of the actions for the user with the given Id. This will return all time based actions that are active,
     * and inactive as well as non-time based actions.
     *
     * @param {string} userId The Id of the user to fetch the actions for.
     * @returns {Promise<ClientResponse<ActionResponse>>}
     */
    retrieveActions(userId: string): Promise<ClientResponse<ActionResponse>>;
    /**
     * Retrieves all of the actions for the user with the given Id that are currently preventing the User from logging in.
     *
     * @param {string} userId The Id of the user to fetch the actions for.
     * @returns {Promise<ClientResponse<ActionResponse>>}
     */
    retrieveActionsPreventingLogin(userId: string): Promise<ClientResponse<ActionResponse>>;
    /**
     * Retrieves all of the actions for the user with the given Id that are currently active.
     * An active action means one that is time based and has not been canceled, and has not ended.
     *
     * @param {string} userId The Id of the user to fetch the actions for.
     * @returns {Promise<ClientResponse<ActionResponse>>}
     */
    retrieveActiveActions(userId: string): Promise<ClientResponse<ActionResponse>>;
    /**
     * Retrieves the application for the given id or all of the applications if the id is null.
     *
     * @param {string} applicationId (Optional) The application id.
     * @returns {Promise<ClientResponse<ApplicationResponse>>}
     */
    retrieveApplication(applicationId: string): Promise<ClientResponse<ApplicationResponse>>;
    /**
     * Retrieves all of the applications.
     *
     * @returns {Promise<ClientResponse<ApplicationResponse>>}
     */
    retrieveApplications(): Promise<ClientResponse<ApplicationResponse>>;
    /**
     * Retrieves a single audit log for the given Id.
     *
     * @param {number} auditLogId The Id of the audit log to retrieve.
     * @returns {Promise<ClientResponse<AuditLogResponse>>}
     */
    retrieveAuditLog(auditLogId: number): Promise<ClientResponse<AuditLogResponse>>;
    /**
     * Retrieves the Consent for the given Id.
     *
     * @param {string} consentId The Id of the consent.
     * @returns {Promise<ClientResponse<ConsentResponse>>}
     */
    retrieveConsent(consentId: string): Promise<ClientResponse<ConsentResponse>>;
    /**
     * Retrieves all of the consent.
     *
     * @returns {Promise<ClientResponse<ConsentResponse>>}
     */
    retrieveConsents(): Promise<ClientResponse<ConsentResponse>>;
    /**
     * Retrieves the daily active user report between the two instants. If you specify an application id, it will only
     * return the daily active counts for that application.
     *
     * @param {string} applicationId (Optional) The application id.
     * @param {number} start The start instant as UTC milliseconds since Epoch.
     * @param {number} end The end instant as UTC milliseconds since Epoch.
     * @returns {Promise<ClientResponse<DailyActiveUserReportResponse>>}
     */
    retrieveDailyActiveReport(applicationId: string, start: number, end: number): Promise<ClientResponse<DailyActiveUserReportResponse>>;
    /**
     * Retrieves the email template for the given Id. If you don't specify the id, this will return all of the email templates.
     *
     * @param {string} emailTemplateId (Optional) The Id of the email template.
     * @returns {Promise<ClientResponse<EmailTemplateResponse>>}
     */
    retrieveEmailTemplate(emailTemplateId: string): Promise<ClientResponse<EmailTemplateResponse>>;
    /**
     * Creates a preview of the email template provided in the request. This allows you to preview an email template that
     * hasn't been saved to the database yet. The entire email template does not need to be provided on the request. This
     * will create the preview based on whatever is given.
     *
     * @param {PreviewRequest} request The request that contains the email template and optionally a locale to render it in.
     * @returns {Promise<ClientResponse<PreviewResponse>>}
     */
    retrieveEmailTemplatePreview(request: PreviewRequest): Promise<ClientResponse<PreviewResponse>>;
    /**
     * Retrieves all of the email templates.
     *
     * @returns {Promise<ClientResponse<EmailTemplateResponse>>}
     */
    retrieveEmailTemplates(): Promise<ClientResponse<EmailTemplateResponse>>;
    /**
     * Retrieves a single event log for the given Id.
     *
     * @param {number} eventLogId The Id of the event log to retrieve.
     * @returns {Promise<ClientResponse<EventLogResponse>>}
     */
    retrieveEventLog(eventLogId: number): Promise<ClientResponse<EventLogResponse>>;
    /**
     * Retrieves all of the families that a user belongs to.
     *
     * @param {string} userId The User's id
     * @returns {Promise<ClientResponse<FamilyResponse>>}
     */
    retrieveFamilies(userId: string): Promise<ClientResponse<FamilyResponse>>;
    /**
     * Retrieves all of the members of a family by the unique Family Id.
     *
     * @param {string} familyId The unique Id of the Family.
     * @returns {Promise<ClientResponse<FamilyResponse>>}
     */
    retrieveFamilyMembersByFamilyId(familyId: string): Promise<ClientResponse<FamilyResponse>>;
    /**
     * Retrieves the group for the given Id.
     *
     * @param {string} groupId The Id of the group.
     * @returns {Promise<ClientResponse<GroupResponse>>}
     */
    retrieveGroup(groupId: string): Promise<ClientResponse<GroupResponse>>;
    /**
     * Retrieves all of the groups.
     *
     * @returns {Promise<ClientResponse<GroupResponse>>}
     */
    retrieveGroups(): Promise<ClientResponse<GroupResponse>>;
    /**
     * Retrieves the identity provider for the given id or all of the identity providers if the id is null.
     *
     * @param {string} identityProviderId (Optional) The identity provider id.
     * @returns {Promise<ClientResponse<IdentityProviderResponse>>}
     */
    retrieveIdentityProvider(identityProviderId: string): Promise<ClientResponse<IdentityProviderResponse>>;
    /**
     * Retrieves all of the identity providers.
     *
     * @returns {Promise<ClientResponse<IdentityProviderResponse>>}
     */
    retrieveIdentityProviders(): Promise<ClientResponse<IdentityProviderResponse>>;
    /**
     * Retrieves all of the actions for the user with the given Id that are currently inactive.
     * An inactive action means one that is time based and has been canceled or has expired, or is not time based.
     *
     * @param {string} userId The Id of the user to fetch the actions for.
     * @returns {Promise<ClientResponse<ActionResponse>>}
     */
    retrieveInactiveActions(userId: string): Promise<ClientResponse<ActionResponse>>;
    /**
     * Retrieves all of the applications that are currently inactive.
     *
     * @returns {Promise<ClientResponse<ApplicationResponse>>}
     */
    retrieveInactiveApplications(): Promise<ClientResponse<ApplicationResponse>>;
    /**
     * Retrieves all of the user actions that are currently inactive.
     *
     * @returns {Promise<ClientResponse<UserActionResponse>>}
     */
    retrieveInactiveUserActions(): Promise<ClientResponse<UserActionResponse>>;
    /**
     * Retrieves the available integrations.
     *
     * @returns {Promise<ClientResponse<IntegrationResponse>>}
     */
    retrieveIntegration(): Promise<ClientResponse<IntegrationResponse>>;
    /**
     * Retrieves the Public Key configured for verifying JSON Web Tokens (JWT) by the key Id (kid).
     *
     * @param {string} keyId The Id of the public key (kid).
     * @returns {Promise<ClientResponse<PublicKeyResponse>>}
     */
    retrieveJWTPublicKey(keyId: string): Promise<ClientResponse<PublicKeyResponse>>;
    /**
     * Retrieves the Public Key configured for verifying the JSON Web Tokens (JWT) issued by the Login API by the Application Id.
     *
     * @param {string} applicationId The Id of the Application for which this key is used.
     * @returns {Promise<ClientResponse<PublicKeyResponse>>}
     */
    retrieveJWTPublicKeyByApplicationId(applicationId: string): Promise<ClientResponse<PublicKeyResponse>>;
    /**
     * Retrieves all Public Keys configured for verifying JSON Web Tokens (JWT).
     *
     * @returns {Promise<ClientResponse<PublicKeyResponse>>}
     */
    retrieveJWTPublicKeys(): Promise<ClientResponse<PublicKeyResponse>>;
    /**
     * Retrieves the key for the given Id.
     *
     * @param {string} keyId The Id of the key.
     * @returns {Promise<ClientResponse<KeyResponse>>}
     */
    retrieveKey(keyId: string): Promise<ClientResponse<KeyResponse>>;
    /**
     * Retrieves all of the keys.
     *
     * @returns {Promise<ClientResponse<KeyResponse>>}
     */
    retrieveKeys(): Promise<ClientResponse<KeyResponse>>;
    /**
     * Retrieves the lambda for the given Id.
     *
     * @param {string} lambdaId The Id of the lambda.
     * @returns {Promise<ClientResponse<LambdaResponse>>}
     */
    retrieveLambda(lambdaId: string): Promise<ClientResponse<LambdaResponse>>;
    /**
     * Retrieves all of the lambdas.
     *
     * @returns {Promise<ClientResponse<LambdaResponse>>}
     */
    retrieveLambdas(): Promise<ClientResponse<LambdaResponse>>;
    /**
     * Retrieves all of the lambdas for the provided type.
     *
     * @param {LambdaType} type The type of the lambda to return.
     * @returns {Promise<ClientResponse<LambdaResponse>>}
     */
    retrieveLambdasByType(type: LambdaType): Promise<ClientResponse<LambdaResponse>>;
    /**
     * Retrieves the login report between the two instants. If you specify an application id, it will only return the
     * login counts for that application.
     *
     * @param {string} applicationId (Optional) The application id.
     * @param {number} start The start instant as UTC milliseconds since Epoch.
     * @param {number} end The end instant as UTC milliseconds since Epoch.
     * @returns {Promise<ClientResponse<LoginReportResponse>>}
     */
    retrieveLoginReport(applicationId: string, start: number, end: number): Promise<ClientResponse<LoginReportResponse>>;
    /**
     * Retrieves the monthly active user report between the two instants. If you specify an application id, it will only
     * return the monthly active counts for that application.
     *
     * @param {string} applicationId (Optional) The application id.
     * @param {number} start The start instant as UTC milliseconds since Epoch.
     * @param {number} end The end instant as UTC milliseconds since Epoch.
     * @returns {Promise<ClientResponse<MonthlyActiveUserReportResponse>>}
     */
    retrieveMonthlyActiveReport(applicationId: string, start: number, end: number): Promise<ClientResponse<MonthlyActiveUserReportResponse>>;
    /**
     * Retrieves the Oauth2 configuration for the application for the given Application Id.
     *
     * @param {string} applicationId The Id of the Application to retrieve OAuth configuration.
     * @returns {Promise<ClientResponse<OAuthConfigurationResponse>>}
     */
    retrieveOauthConfiguration(applicationId: string): Promise<ClientResponse<OAuthConfigurationResponse>>;
    /**
     * Retrieves the password validation rules for a specific tenant. This method requires a tenantId to be provided
     * through the use of a Tenant scoped API key or an HTTP header X-FusionAuth-TenantId to specify the Tenant Id.
     *
     * This API does not require an API key.
     *
     * @returns {Promise<ClientResponse<PasswordValidationRulesResponse>>}
     */
    retrievePasswordValidationRules(): Promise<ClientResponse<PasswordValidationRulesResponse>>;
    /**
     * Retrieves the password validation rules for a specific tenant.
     *
     * This API does not require an API key.
     *
     * @param {string} tenantId The Id of the tenant.
     * @returns {Promise<ClientResponse<PasswordValidationRulesResponse>>}
     */
    retrievePasswordValidationRulesWithTenantId(tenantId: string): Promise<ClientResponse<PasswordValidationRulesResponse>>;
    /**
     * Retrieves all of the children for the given parent email address.
     *
     * @param {string} parentEmail The email of the parent.
     * @returns {Promise<ClientResponse<PendingResponse>>}
     */
    retrievePendingChildren(parentEmail: string): Promise<ClientResponse<PendingResponse>>;
    /**
     * Retrieves the last number of login records.
     *
     * @param {number} offset The initial record. e.g. 0 is the last login, 100 will be the 100th most recent login.
     * @param {number} limit (Optional, defaults to 10) The number of records to retrieve.
     * @returns {Promise<ClientResponse<RecentLoginResponse>>}
     */
    retrieveRecentLogins(offset: number, limit: number): Promise<ClientResponse<RecentLoginResponse>>;
    /**
     * Retrieves the refresh tokens that belong to the user with the given Id.
     *
     * @param {string} userId The Id of the user.
     * @returns {Promise<ClientResponse<RefreshResponse>>}
     */
    retrieveRefreshTokens(userId: string): Promise<ClientResponse<RefreshResponse>>;
    /**
     * Retrieves the user registration for the user with the given id and the given application id.
     *
     * @param {string} userId The Id of the user.
     * @param {string} applicationId The Id of the application.
     * @returns {Promise<ClientResponse<RegistrationResponse>>}
     */
    retrieveRegistration(userId: string, applicationId: string): Promise<ClientResponse<RegistrationResponse>>;
    /**
     * Retrieves the registration report between the two instants. If you specify an application id, it will only return
     * the registration counts for that application.
     *
     * @param {string} applicationId (Optional) The application id.
     * @param {number} start The start instant as UTC milliseconds since Epoch.
     * @param {number} end The end instant as UTC milliseconds since Epoch.
     * @returns {Promise<ClientResponse<RegistrationReportResponse>>}
     */
    retrieveRegistrationReport(applicationId: string, start: number, end: number): Promise<ClientResponse<RegistrationReportResponse>>;
    /**
     * Retrieves the system configuration.
     *
     * @returns {Promise<ClientResponse<SystemConfigurationResponse>>}
     */
    retrieveSystemConfiguration(): Promise<ClientResponse<SystemConfigurationResponse>>;
    /**
     * Retrieves the tenant for the given Id.
     *
     * @param {string} tenantId The Id of the tenant.
     * @returns {Promise<ClientResponse<TenantResponse>>}
     */
    retrieveTenant(tenantId: string): Promise<ClientResponse<TenantResponse>>;
    /**
     * Retrieves all of the tenants.
     *
     * @returns {Promise<ClientResponse<TenantResponse>>}
     */
    retrieveTenants(): Promise<ClientResponse<TenantResponse>>;
    /**
     * Retrieves the theme for the given Id.
     *
     * @param {string} themeId The Id of the theme.
     * @returns {Promise<ClientResponse<ThemeResponse>>}
     */
    retrieveTheme(themeId: string): Promise<ClientResponse<ThemeResponse>>;
    /**
     * Retrieves all of the themes.
     *
     * @returns {Promise<ClientResponse<ThemeResponse>>}
     */
    retrieveThemes(): Promise<ClientResponse<ThemeResponse>>;
    /**
     * Retrieves the totals report. This contains all of the total counts for each application and the global registration
     * count.
     *
     * @returns {Promise<ClientResponse<TotalsReportResponse>>}
     */
    retrieveTotalReport(): Promise<ClientResponse<TotalsReportResponse>>;
    /**
     * Retrieves the user for the given Id.
     *
     * @param {string} userId The Id of the user.
     * @returns {Promise<ClientResponse<UserResponse>>}
     */
    retrieveUser(userId: string): Promise<ClientResponse<UserResponse>>;
    /**
     * Retrieves the user action for the given Id. If you pass in null for the id, this will return all of the user
     * actions.
     *
     * @param {string} userActionId (Optional) The Id of the user action.
     * @returns {Promise<ClientResponse<UserActionResponse>>}
     */
    retrieveUserAction(userActionId: string): Promise<ClientResponse<UserActionResponse>>;
    /**
     * Retrieves the user action reason for the given Id. If you pass in null for the id, this will return all of the user
     * action reasons.
     *
     * @param {string} userActionReasonId (Optional) The Id of the user action reason.
     * @returns {Promise<ClientResponse<UserActionReasonResponse>>}
     */
    retrieveUserActionReason(userActionReasonId: string): Promise<ClientResponse<UserActionReasonResponse>>;
    /**
     * Retrieves all the user action reasons.
     *
     * @returns {Promise<ClientResponse<UserActionReasonResponse>>}
     */
    retrieveUserActionReasons(): Promise<ClientResponse<UserActionReasonResponse>>;
    /**
     * Retrieves all of the user actions.
     *
     * @returns {Promise<ClientResponse<UserActionResponse>>}
     */
    retrieveUserActions(): Promise<ClientResponse<UserActionResponse>>;
    /**
     * Retrieves the user by a change password Id. The intended use of this API is to retrieve a user after the forgot
     * password workflow has been initiated and you may not know the user's email or username.
     *
     * @param {string} changePasswordId The unique change password Id that was sent via email or returned by the Forgot Password API.
     * @returns {Promise<ClientResponse<UserResponse>>}
     */
    retrieveUserByChangePasswordId(changePasswordId: string): Promise<ClientResponse<UserResponse>>;
    /**
     * Retrieves the user for the given email.
     *
     * @param {string} email The email of the user.
     * @returns {Promise<ClientResponse<UserResponse>>}
     */
    retrieveUserByEmail(email: string): Promise<ClientResponse<UserResponse>>;
    /**
     * Retrieves the user for the loginId. The loginId can be either the username or the email.
     *
     * @param {string} loginId The email or username of the user.
     * @returns {Promise<ClientResponse<UserResponse>>}
     */
    retrieveUserByLoginId(loginId: string): Promise<ClientResponse<UserResponse>>;
    /**
     * Retrieves the user for the given username.
     *
     * @param {string} username The username of the user.
     * @returns {Promise<ClientResponse<UserResponse>>}
     */
    retrieveUserByUsername(username: string): Promise<ClientResponse<UserResponse>>;
    /**
     * Retrieves the user by a verificationId. The intended use of this API is to retrieve a user after the forgot
     * password workflow has been initiated and you may not know the user's email or username.
     *
     * @param {string} verificationId The unique verification Id that has been set on the user object.
     * @returns {Promise<ClientResponse<UserResponse>>}
     */
    retrieveUserByVerificationId(verificationId: string): Promise<ClientResponse<UserResponse>>;
    /**
     * Retrieves all of the comments for the user with the given Id.
     *
     * @param {string} userId The Id of the user.
     * @returns {Promise<ClientResponse<UserCommentResponse>>}
     */
    retrieveUserComments(userId: string): Promise<ClientResponse<UserCommentResponse>>;
    /**
     * Retrieve a single User consent by Id.
     *
     * @param {string} userConsentId The User consent Id
     * @returns {Promise<ClientResponse<UserConsentResponse>>}
     */
    retrieveUserConsent(userConsentId: string): Promise<ClientResponse<UserConsentResponse>>;
    /**
     * Retrieves all of the consents for a User.
     *
     * @param {string} userId The User's Id
     * @returns {Promise<ClientResponse<UserConsentResponse>>}
     */
    retrieveUserConsents(userId: string): Promise<ClientResponse<UserConsentResponse>>;
    /**
     * Retrieves the login report between the two instants for a particular user by Id. If you specify an application id, it will only return the
     * login counts for that application.
     *
     * @param {string} applicationId (Optional) The application id.
     * @param {string} userId The userId id.
     * @param {number} start The start instant as UTC milliseconds since Epoch.
     * @param {number} end The end instant as UTC milliseconds since Epoch.
     * @returns {Promise<ClientResponse<LoginReportResponse>>}
     */
    retrieveUserLoginReport(applicationId: string, userId: string, start: number, end: number): Promise<ClientResponse<LoginReportResponse>>;
    /**
     * Retrieves the login report between the two instants for a particular user by login Id. If you specify an application id, it will only return the
     * login counts for that application.
     *
     * @param {string} applicationId (Optional) The application id.
     * @param {string} loginId The userId id.
     * @param {number} start The start instant as UTC milliseconds since Epoch.
     * @param {number} end The end instant as UTC milliseconds since Epoch.
     * @returns {Promise<ClientResponse<LoginReportResponse>>}
     */
    retrieveUserLoginReportByLoginId(applicationId: string, loginId: string, start: number, end: number): Promise<ClientResponse<LoginReportResponse>>;
    /**
     * Retrieves the last number of login records for a user.
     *
     * @param {string} userId The Id of the user.
     * @param {number} offset The initial record. e.g. 0 is the last login, 100 will be the 100th most recent login.
     * @param {number} limit (Optional, defaults to 10) The number of records to retrieve.
     * @returns {Promise<ClientResponse<RecentLoginResponse>>}
     */
    retrieveUserRecentLogins(userId: string, offset: number, limit: number): Promise<ClientResponse<RecentLoginResponse>>;
    /**
     * Retrieves the user for the given Id. This method does not use an API key, instead it uses a JSON Web Token (JWT) for authentication.
     *
     * @param {string} encodedJWT The encoded JWT (access token).
     * @returns {Promise<ClientResponse<UserResponse>>}
     */
    retrieveUserUsingJWT(encodedJWT: string): Promise<ClientResponse<UserResponse>>;
    /**
     * Retrieves the webhook for the given Id. If you pass in null for the id, this will return all the webhooks.
     *
     * @param {string} webhookId (Optional) The Id of the webhook.
     * @returns {Promise<ClientResponse<WebhookResponse>>}
     */
    retrieveWebhook(webhookId: string): Promise<ClientResponse<WebhookResponse>>;
    /**
     * Retrieves all the webhooks.
     *
     * @returns {Promise<ClientResponse<WebhookResponse>>}
     */
    retrieveWebhooks(): Promise<ClientResponse<WebhookResponse>>;
    /**
     * Revokes a single refresh token, all tokens for a user or all tokens for an application. If you provide a user id
     * and an application id, this will delete all the refresh tokens for that user for that application.
     *
     * @param {string} token (Optional) The refresh token to delete.
     * @param {string} userId (Optional) The user id whose tokens to delete.
     * @param {string} applicationId (Optional) The application id of the tokens to delete.
     * @returns {Promise<ClientResponse<void>>}
     */
    revokeRefreshToken(token: string, userId: string, applicationId: string): Promise<ClientResponse<void>>;
    /**
     * Revokes a single User consent by Id.
     *
     * @param {string} userConsentId The User Consent Id
     * @returns {Promise<ClientResponse<void>>}
     */
    revokeUserConsent(userConsentId: string): Promise<ClientResponse<void>>;
    /**
     * Searches the audit logs with the specified criteria and pagination.
     *
     * @param {AuditLogSearchRequest} request The search criteria and pagination information.
     * @returns {Promise<ClientResponse<AuditLogSearchResponse>>}
     */
    searchAuditLogs(request: AuditLogSearchRequest): Promise<ClientResponse<AuditLogSearchResponse>>;
    /**
     * Searches the event logs with the specified criteria and pagination.
     *
     * @param {EventLogSearchRequest} request The search criteria and pagination information.
     * @returns {Promise<ClientResponse<EventLogSearchResponse>>}
     */
    searchEventLogs(request: EventLogSearchRequest): Promise<ClientResponse<EventLogSearchResponse>>;
    /**
     * Searches the login records with the specified criteria and pagination.
     *
     * @param {LoginRecordSearchRequest} request The search criteria and pagination information.
     * @returns {Promise<ClientResponse<LoginRecordSearchResponse>>}
     */
    searchLoginRecords(request: LoginRecordSearchRequest): Promise<ClientResponse<LoginRecordSearchResponse>>;
    /**
     * Retrieves the users for the given ids. If any id is invalid, it is ignored.
     *
     * @param {Array<string>} ids The user ids to search for.
     * @returns {Promise<ClientResponse<SearchResponse>>}
     */
    searchUsers(ids: Array<string>): Promise<ClientResponse<SearchResponse>>;
    /**
     * Retrieves the users for the given search criteria and pagination.
     *
     * @param {SearchRequest} request The search criteria and pagination constraints. Fields used: queryString, numberOfResults, startRow,
     *    and sort fields.
     * @returns {Promise<ClientResponse<SearchResponse>>}
     */
    searchUsersByQueryString(request: SearchRequest): Promise<ClientResponse<SearchResponse>>;
    /**
     * Send an email using an email template id. You can optionally provide <code>requestData</code> to access key value
     * pairs in the email template.
     *
     * @param {string} emailTemplateId The id for the template.
     * @param {SendRequest} request The send email request that contains all of the information used to send the email.
     * @returns {Promise<ClientResponse<SendResponse>>}
     */
    sendEmail(emailTemplateId: string, request: SendRequest): Promise<ClientResponse<SendResponse>>;
    /**
     * Sends out an email to a parent that they need to register and create a family or need to log in and add a child to their existing family.
     *
     * @param {FamilyEmailRequest} request The request object that contains the parent email.
     * @returns {Promise<ClientResponse<void>>}
     */
    sendFamilyRequestEmail(request: FamilyEmailRequest): Promise<ClientResponse<void>>;
    /**
     * Send a passwordless authentication code in an email to complete login.
     *
     * @param {PasswordlessSendRequest} request The passwordless send request that contains all of the information used to send an email containing a code.
     * @returns {Promise<ClientResponse<void>>}
     */
    sendPasswordlessCode(request: PasswordlessSendRequest): Promise<ClientResponse<void>>;
    /**
     * Send a Two Factor authentication code to assist in setting up Two Factor authentication or disabling.
     *
     * @param {TwoFactorSendRequest} request The request object that contains all of the information used to send the code.
     * @returns {Promise<ClientResponse<void>>}
     */
    sendTwoFactorCode(request: TwoFactorSendRequest): Promise<ClientResponse<void>>;
    /**
     * Send a Two Factor authentication code to allow the completion of Two Factor authentication.
     *
     * @param {string} twoFactorId The Id returned by the Login API necessary to complete Two Factor authentication.
     * @returns {Promise<ClientResponse<void>>}
     */
    sendTwoFactorCodeForLogin(twoFactorId: string): Promise<ClientResponse<void>>;
    /**
     * Complete login using a 2FA challenge
     *
     * @param {TwoFactorLoginRequest} request The login request that contains the user credentials used to log them in.
     * @returns {Promise<ClientResponse<LoginResponse>>}
     */
    twoFactorLogin(request: TwoFactorLoginRequest): Promise<ClientResponse<LoginResponse>>;
    /**
     * Updates the application with the given Id.
     *
     * @param {string} applicationId The Id of the application to update.
     * @param {ApplicationRequest} request The request that contains all of the new application information.
     * @returns {Promise<ClientResponse<ApplicationResponse>>}
     */
    updateApplication(applicationId: string, request: ApplicationRequest): Promise<ClientResponse<ApplicationResponse>>;
    /**
     * Updates the application role with the given id for the application.
     *
     * @param {string} applicationId The Id of the application that the role belongs to.
     * @param {string} roleId The Id of the role to update.
     * @param {ApplicationRequest} request The request that contains all of the new role information.
     * @returns {Promise<ClientResponse<ApplicationResponse>>}
     */
    updateApplicationRole(applicationId: string, roleId: string, request: ApplicationRequest): Promise<ClientResponse<ApplicationResponse>>;
    /**
     * Updates the consent with the given Id.
     *
     * @param {string} consentId The Id of the consent to update.
     * @param {ConsentRequest} request The request that contains all of the new consent information.
     * @returns {Promise<ClientResponse<ConsentResponse>>}
     */
    updateConsent(consentId: string, request: ConsentRequest): Promise<ClientResponse<ConsentResponse>>;
    /**
     * Updates the email template with the given Id.
     *
     * @param {string} emailTemplateId The Id of the email template to update.
     * @param {EmailTemplateRequest} request The request that contains all of the new email template information.
     * @returns {Promise<ClientResponse<EmailTemplateResponse>>}
     */
    updateEmailTemplate(emailTemplateId: string, request: EmailTemplateRequest): Promise<ClientResponse<EmailTemplateResponse>>;
    /**
     * Updates the group with the given Id.
     *
     * @param {string} groupId The Id of the group to update.
     * @param {GroupRequest} request The request that contains all of the new group information.
     * @returns {Promise<ClientResponse<GroupResponse>>}
     */
    updateGroup(groupId: string, request: GroupRequest): Promise<ClientResponse<GroupResponse>>;
    /**
     * Updates the identity provider with the given Id.
     *
     * @param {string} identityProviderId The Id of the identity provider to update.
     * @param {IdentityProviderRequest} request The request object that contains the updated identity provider.
     * @returns {Promise<ClientResponse<IdentityProviderResponse>>}
     */
    updateIdentityProvider(identityProviderId: string, request: IdentityProviderRequest): Promise<ClientResponse<IdentityProviderResponse>>;
    /**
     * Updates the available integrations.
     *
     * @param {IntegrationRequest} request The request that contains all of the new integration information.
     * @returns {Promise<ClientResponse<IntegrationResponse>>}
     */
    updateIntegrations(request: IntegrationRequest): Promise<ClientResponse<IntegrationResponse>>;
    /**
     * Updates the key with the given Id.
     *
     * @param {string} keyId The Id of the key to update.
     * @param {KeyRequest} request The request that contains all of the new key information.
     * @returns {Promise<ClientResponse<KeyResponse>>}
     */
    updateKey(keyId: string, request: KeyRequest): Promise<ClientResponse<KeyResponse>>;
    /**
     * Updates the lambda with the given Id.
     *
     * @param {string} lambdaId The Id of the lambda to update.
     * @param {LambdaRequest} request The request that contains all of the new lambda information.
     * @returns {Promise<ClientResponse<LambdaResponse>>}
     */
    updateLambda(lambdaId: string, request: LambdaRequest): Promise<ClientResponse<LambdaResponse>>;
    /**
     * Updates the registration for the user with the given id and the application defined in the request.
     *
     * @param {string} userId The Id of the user whose registration is going to be updated.
     * @param {RegistrationRequest} request The request that contains all of the new registration information.
     * @returns {Promise<ClientResponse<RegistrationResponse>>}
     */
    updateRegistration(userId: string, request: RegistrationRequest): Promise<ClientResponse<RegistrationResponse>>;
    /**
     * Updates the system configuration.
     *
     * @param {SystemConfigurationRequest} request The request that contains all of the new system configuration information.
     * @returns {Promise<ClientResponse<SystemConfigurationResponse>>}
     */
    updateSystemConfiguration(request: SystemConfigurationRequest): Promise<ClientResponse<SystemConfigurationResponse>>;
    /**
     * Updates the tenant with the given Id.
     *
     * @param {string} tenantId The Id of the tenant to update.
     * @param {TenantRequest} request The request that contains all of the new tenant information.
     * @returns {Promise<ClientResponse<TenantResponse>>}
     */
    updateTenant(tenantId: string, request: TenantRequest): Promise<ClientResponse<TenantResponse>>;
    /**
     * Updates the theme with the given Id.
     *
     * @param {string} themeId The Id of the theme to update.
     * @param {ThemeRequest} request The request that contains all of the new theme information.
     * @returns {Promise<ClientResponse<ThemeResponse>>}
     */
    updateTheme(themeId: string, request: ThemeRequest): Promise<ClientResponse<ThemeResponse>>;
    /**
     * Updates the user with the given Id.
     *
     * @param {string} userId The Id of the user to update.
     * @param {UserRequest} request The request that contains all of the new user information.
     * @returns {Promise<ClientResponse<UserResponse>>}
     */
    updateUser(userId: string, request: UserRequest): Promise<ClientResponse<UserResponse>>;
    /**
     * Updates the user action with the given Id.
     *
     * @param {string} userActionId The Id of the user action to update.
     * @param {UserActionRequest} request The request that contains all of the new user action information.
     * @returns {Promise<ClientResponse<UserActionResponse>>}
     */
    updateUserAction(userActionId: string, request: UserActionRequest): Promise<ClientResponse<UserActionResponse>>;
    /**
     * Updates the user action reason with the given Id.
     *
     * @param {string} userActionReasonId The Id of the user action reason to update.
     * @param {UserActionReasonRequest} request The request that contains all of the new user action reason information.
     * @returns {Promise<ClientResponse<UserActionReasonResponse>>}
     */
    updateUserActionReason(userActionReasonId: string, request: UserActionReasonRequest): Promise<ClientResponse<UserActionReasonResponse>>;
    /**
     * Updates a single User consent by Id.
     *
     * @param {string} userConsentId The User Consent Id
     * @param {UserConsentRequest} request The request that contains the user consent information.
     * @returns {Promise<ClientResponse<UserConsentResponse>>}
     */
    updateUserConsent(userConsentId: string, request: UserConsentRequest): Promise<ClientResponse<UserConsentResponse>>;
    /**
     * Updates the webhook with the given Id.
     *
     * @param {string} webhookId The Id of the webhook to update.
     * @param {WebhookRequest} request The request that contains all of the new webhook information.
     * @returns {Promise<ClientResponse<WebhookResponse>>}
     */
    updateWebhook(webhookId: string, request: WebhookRequest): Promise<ClientResponse<WebhookResponse>>;
    /**
     * Validates the provided JWT (encoded JWT string) to ensure the token is valid. A valid access token is properly
     * signed and not expired.
     * <p>
     * This API may be used to verify the JWT as well as decode the encoded JWT into human readable identity claims.
     *
     * @param {string} encodedJWT The encoded JWT (access token).
     * @returns {Promise<ClientResponse<ValidateResponse>>}
     */
    validateJWT(encodedJWT: string): Promise<ClientResponse<ValidateResponse>>;
    /**
     * Confirms a email verification. The Id given is usually from an email sent to the user.
     *
     * @param {string} verificationId The email verification id sent to the user.
     * @returns {Promise<ClientResponse<void>>}
     */
    verifyEmail(verificationId: string): Promise<ClientResponse<void>>;
    /**
     * Confirms an application registration. The Id given is usually from an email sent to the user.
     *
     * @param {string} verificationId The registration verification Id sent to the user.
     * @returns {Promise<ClientResponse<void>>}
     */
    verifyRegistration(verificationId: string): Promise<ClientResponse<void>>;
    /**
     * creates a rest client
     *
     * @returns {IRestClient} The RESTClient that will be used to call.
     * @private
     */
    private start;
}
/**
 * @author Daniel DeGroff
 */
export interface AccessToken {
    access_token?: string;
    clientId?: string;
    expires_in?: number;
    id_token?: string;
    redirectURI?: string;
    refresh_token?: string;
    scope?: string;
    token_type?: TokenType;
    userId?: string;
}
export interface ActionData {
    action?: UserAction;
    actionee?: User;
    actioneeUserId?: string;
    actioner?: User;
    actionerUserId?: string;
    applicationIds?: Array<string>;
    comment?: string;
    emailUser?: boolean;
    expiry?: number;
    log?: UserActionLog;
    notifyUser?: boolean;
    option?: string;
    reason?: UserActionReason;
    reasonId?: string;
    userActionId?: string;
}
/**
 * The user action request object.
 *
 * @author Brian Pontarelli
 */
export interface ActionRequest {
    action?: ActionData;
    broadcast?: boolean;
}
/**
 * The user action response object.
 *
 * @author Brian Pontarelli
 */
export interface ActionResponse {
    action?: UserActionLog;
    actions?: Array<UserActionLog>;
}
/**
 * Available JSON Web Algorithms (JWA) as described in RFC 7518 available for this JWT implementation.
 *
 * @author Daniel DeGroff
 */
export declare enum Algorithm {
    ES256 = 0,
    ES384 = 1,
    ES512 = 2,
    HS256 = 3,
    HS384 = 4,
    HS512 = 5,
    RS256 = 6,
    RS384 = 7,
    RS512 = 8,
    none = 9
}
/**
 * @author Seth Musselman
 */
export interface Application {
    active?: boolean;
    authenticationTokenConfiguration?: AuthenticationTokenConfiguration;
    cleanSpeakConfiguration?: CleanSpeakConfiguration;
    data?: Map<string, any>;
    id?: string;
    jwtConfiguration?: JWTConfiguration;
    lambdaConfiguration?: LambdaConfiguration;
    loginConfiguration?: LoginConfiguration;
    name?: string;
    oauthConfiguration?: OAuth2Configuration;
    passwordlessConfiguration?: PasswordlessConfiguration;
    registrationConfiguration?: RegistrationConfiguration;
    roles?: Array<ApplicationRole>;
    samlv2Configuration?: SAMLv2Configuration;
    tenantId?: string;
    verificationEmailTemplateId?: string;
    verifyRegistration?: boolean;
}
/**
 * Events that are bound to applications.
 *
 * @author Brian Pontarelli
 */
export interface ApplicationEvent {
}
/**
 * The Application API request object.
 *
 * @author Brian Pontarelli
 */
export interface ApplicationRequest {
    application?: Application;
    role?: ApplicationRole;
    webhookIds?: Array<string>;
}
/**
 * The Application API response.
 *
 * @author Brian Pontarelli
 */
export interface ApplicationResponse {
    application?: Application;
    applications?: Array<Application>;
    role?: ApplicationRole;
}
/**
 * A role given to a user for a specific application.
 *
 * @author Seth Musselman
 */
export interface ApplicationRole {
    applicationId?: string;
    description?: string;
    display?: string;
    id?: string;
    isDefault?: boolean;
    isSuperRole?: boolean;
    name?: string;
}
/**
 * This class is a simple attachment with a byte array, name and MIME type.
 *
 * @author Brian Pontarelli
 */
export interface Attachment {
    attachment?: Array<number>;
    mime?: string;
    name?: string;
}
/**
 * An audit log.
 *
 * @author Brian Pontarelli
 */
export interface AuditLog {
    data?: Map<string, any>;
    id?: number;
    insertInstant?: number;
    insertUser?: string;
    message?: string;
    newValue?: any;
    oldValue?: any;
    reason?: string;
}
export interface AuditLogConfiguration {
    delete?: DeleteConfiguration;
}
/**
 * @author Daniel DeGroff
 */
export interface AuditLogExportRequest extends BaseExportRequest {
    criteria?: AuditLogSearchCriteria;
}
/**
 * @author Brian Pontarelli
 */
export interface AuditLogRequest {
    auditLog?: AuditLog;
}
/**
 * Audit log response.
 *
 * @author Brian Pontarelli
 */
export interface AuditLogResponse {
    auditLog?: AuditLog;
}
/**
 * @author Brian Pontarelli
 */
export interface AuditLogSearchCriteria extends BaseSearchCriteria {
    end?: number;
    message?: string;
    start?: number;
    user?: string;
}
/**
 * @author Brian Pontarelli
 */
export interface AuditLogSearchRequest {
    search?: AuditLogSearchCriteria;
}
/**
 * Audit log response.
 *
 * @author Brian Pontarelli
 */
export interface AuditLogSearchResponse {
    auditLogs?: Array<AuditLog>;
    total?: number;
}
export interface AuthenticationTokenConfiguration extends Enableable {
}
/**
 * Base-class for all FusionAuth events.
 *
 * @author Brian Pontarelli
 */
export interface BaseEvent {
    createInstant?: number;
    id?: string;
    tenantId?: string;
    type?: EventType;
}
/**
 * @author Daniel DeGroff
 */
export interface BaseExportRequest {
    dateTimeSecondsFormat?: string;
    zoneId?: string;
}
export interface BaseIdentityProvider<D extends BaseIdentityProviderApplicationConfiguration> extends Enableable {
    applicationConfiguration?: Map<string, D>;
    data?: Map<string, any>;
    debug?: boolean;
    id?: string;
    name?: string;
    type?: IdentityProviderType;
}
/**
 * @author Daniel DeGroff
 */
export interface BaseIdentityProviderApplicationConfiguration extends Enableable {
    createRegistration?: boolean;
    data?: Map<string, any>;
}
/**
 * @author Daniel DeGroff
 */
export interface BaseLoginRequest {
    applicationId?: string;
    ipAddress?: string;
    metaData?: MetaData;
    noJWT?: boolean;
}
/**
 * @author Brian Pontarelli
 */
export interface BaseSearchCriteria {
    numberOfResults?: number;
    orderBy?: string;
    startRow?: number;
}
export declare enum CanonicalizationMethod {
    exclusive = 0,
    exclusive_with_comments = 1,
    inclusive = 2,
    inclusive_with_comments = 3
}
export interface CertificateInformation {
    issuer?: string;
    md5Fingerprint?: string;
    serialNumber?: string;
    sha1Fingerprint?: string;
    sha1Thumbprint?: string;
    sha256Fingerprint?: string;
    sha256Thumbprint?: string;
    subject?: string;
    validFrom?: number;
    validTo?: number;
}
/**
 * Change password request object.
 *
 * @author Brian Pontarelli
 */
export interface ChangePasswordRequest {
    currentPassword?: string;
    loginId?: string;
    password?: string;
    refreshToken?: string;
}
/**
 * Change password response object.
 *
 * @author Daniel DeGroff
 */
export interface ChangePasswordResponse {
    oneTimePassword?: string;
    state?: Map<string, any>;
}
/**
 * CleanSpeak configuration at the system and application level.
 *
 * @author Brian Pontarelli
 */
export interface CleanSpeakConfiguration extends Enableable {
    apiKey?: string;
    applicationIds?: Array<string>;
    url?: string;
    usernameModeration?: UsernameModeration;
}
/**
 * Models a consent.
 *
 * @author Daniel DeGroff
 */
export interface Consent {
    consentEmailTemplateId?: string;
    countryMinimumAgeForSelfConsent?: LocalizedIntegers;
    data?: Map<string, any>;
    defaultMinimumAgeForSelfConsent?: number;
    emailPlus?: EmailPlus;
    id?: string;
    multipleValuesAllowed?: boolean;
    name?: string;
    values?: Array<string>;
}
/**
 * API request for User consent types.
 *
 * @author Daniel DeGroff
 */
export interface ConsentRequest {
    consent?: Consent;
}
/**
 * API response for consent.
 *
 * @author Daniel DeGroff
 */
export interface ConsentResponse {
    consent?: Consent;
    consents?: Array<Consent>;
}
/**
 * Models a consent.
 *
 * @author Daniel DeGroff
 */
export declare enum ConsentStatus {
    Active = 0,
    Revoked = 1
}
/**
 * Status for content like usernames, profile attributes, etc.
 *
 * @author Brian Pontarelli
 */
export declare enum ContentStatus {
    ACTIVE = 0,
    PENDING = 1,
    REJECTED = 2
}
export interface CORSConfiguration extends Enableable {
    allowCredentials?: boolean;
    allowedHeaders?: Array<string>;
    allowedMethods?: Array<HTTPMethod>;
    allowedOrigins?: Array<string>;
    exposedHeaders?: Array<string>;
    preflightMaxAgeInSeconds?: number;
}
/**
 * @author Brian Pontarelli
 */
export interface Count {
    count?: number;
    interval?: number;
}
/**
 * Response for the daily active user report.
 *
 * @author Brian Pontarelli
 */
export interface DailyActiveUserReportResponse {
    dailyActiveUsers?: Array<Count>;
    total?: number;
}
export interface DeleteConfiguration extends Enableable {
    numberOfDaysToRetain?: number;
}
/**
 * @author Daniel DeGroff
 */
export interface DeviceInfo {
    description?: string;
    lastAccessedAddress?: string;
    lastAccessedInstant?: number;
    name?: string;
    type?: DeviceType;
}
export declare enum DeviceType {
    BROWSER = 0,
    DESKTOP = 1,
    LAPTOP = 2,
    MOBILE = 3,
    OTHER = 4,
    SERVER = 5,
    TABLET = 6,
    TV = 7,
    UNKNOWN = 8
}
/**
 * A displayable raw login that includes application name and user loginId.
 *
 * @author Brian Pontarelli
 */
export interface DisplayableRawLogin extends RawLogin {
    applicationName?: string;
    loginId?: string;
}
/**
 * Interface for all identity providers that can be domain based.
 */
export interface DomainBasedIdentityProvider {
}
/**
 * This class is an abstraction of a simple email message.
 *
 * @author Brian Pontarelli
 */
export interface Email {
    attachments?: Array<Attachment>;
    bcc?: Array<EmailAddress>;
    cc?: Array<EmailAddress>;
    from?: EmailAddress;
    html?: string;
    replyTo?: EmailAddress;
    subject?: string;
    text?: string;
    to?: Array<EmailAddress>;
}
/**
 * An email address.
 *
 * @author Brian Pontarelli
 */
export interface EmailAddress {
    address?: string;
    display?: string;
}
/**
 * @author Brian Pontarelli
 */
export interface EmailConfiguration {
    forgotPasswordEmailTemplateId?: string;
    host?: string;
    password?: string;
    passwordlessEmailTemplateId?: string;
    port?: number;
    properties?: string;
    security?: EmailSecurityType;
    setPasswordEmailTemplateId?: string;
    username?: string;
    verificationEmailTemplateId?: string;
    verifyEmail?: boolean;
    verifyEmailWhenChanged?: boolean;
}
export interface EmailPlus extends Enableable {
    emailTemplateId?: string;
    maximumTimeToSendEmailInHours?: number;
    minimumTimeToSendEmailInHours?: number;
}
export declare enum EmailSecurityType {
    NONE = 0,
    SSL = 1,
    TLS = 2
}
/**
 * Stores an email template used to send emails to users.
 *
 * @author Brian Pontarelli
 */
export interface EmailTemplate {
    defaultFromName?: string;
    defaultHtmlTemplate?: string;
    defaultSubject?: string;
    defaultTextTemplate?: string;
    fromEmail?: string;
    id?: string;
    localizations?: Set<string>;
    localizedFromNames?: LocalizedStrings;
    localizedHtmlTemplates?: LocalizedStrings;
    localizedSubjects?: LocalizedStrings;
    localizedTextTemplates?: LocalizedStrings;
    name?: string;
}
export interface EmailTemplateErrors {
    parseErrors?: Map<string, string>;
    renderErrors?: Map<string, string>;
}
/**
 * Email template request.
 *
 * @author Brian Pontarelli
 */
export interface EmailTemplateRequest {
    emailTemplate?: EmailTemplate;
}
/**
 * Email template response.
 *
 * @author Brian Pontarelli
 */
export interface EmailTemplateResponse {
    emailTemplate?: EmailTemplate;
    emailTemplates?: Array<EmailTemplate>;
}
/**
 * Something that can be enabled and thus also disabled.
 *
 * @author Daniel DeGroff
 */
export interface Enableable {
    enabled?: boolean;
}
/**
 * Defines an error.
 *
 * @author Brian Pontarelli
 */
export interface Error {
    code?: string;
    message?: string;
    values?: Array<any>;
}
/**
 * Standard error domain object that can also be used as the response from an API call.
 *
 * @author Brian Pontarelli
 */
export interface Errors {
    fieldErrors?: Map<string, Array<Error>>;
    generalErrors?: Array<Error>;
}
/**
 * @author Brian Pontarelli
 */
export interface EventConfiguration {
    events?: Map<EventType, EventConfigurationData>;
}
export interface EventConfigurationData extends Enableable {
    transactionType?: TransactionType;
}
/**
 * Event log used internally by FusionAuth to help developers debug hooks, Webhooks, email templates, etc.
 *
 * @author Brian Pontarelli
 */
export interface EventLog {
    id?: number;
    insertInstant?: number;
    message?: string;
    type?: EventLogType;
}
export interface EventLogConfiguration {
    numberToRetain?: number;
}
/**
 * Event log response.
 *
 * @author Daniel DeGroff
 */
export interface EventLogResponse {
    eventLog?: EventLog;
}
/**
 * Search criteria for the event log.
 *
 * @author Brian Pontarelli
 */
export interface EventLogSearchCriteria extends BaseSearchCriteria {
    end?: number;
    message?: string;
    start?: number;
    type?: EventLogType;
}
/**
 * @author Brian Pontarelli
 */
export interface EventLogSearchRequest {
    search?: EventLogSearchCriteria;
}
/**
 * Event log response.
 *
 * @author Brian Pontarelli
 */
export interface EventLogSearchResponse {
    eventLogs?: Array<EventLog>;
    total?: number;
}
/**
 * Event Log Type
 *
 * @author Daniel DeGroff
 */
export declare enum EventLogType {
    Information = 0,
    Debug = 1,
    Error = 2
}
/**
 * Container for the event information. This is the JSON that is sent from FusionAuth to webhooks.
 *
 * @author Brian Pontarelli
 */
export interface EventRequest {
    event?: BaseEvent;
}
/**
 * Models the event types that FusionAuth produces.
 *
 * @author Brian Pontarelli
 */
export declare enum EventType {
    UserDelete = 0,
    UserCreate = 1,
    UserUpdate = 2,
    UserDeactivate = 3,
    UserBulkCreate = 4,
    UserReactivate = 5,
    UserAction = 6,
    JWTRefreshTokenRevoke = 7,
    JWTPublicKeyUpdate = 8,
    UserLoginSuccess = 9,
    UserLoginFailed = 10,
    UserRegistrationCreate = 11,
    UserRegistrationUpdate = 12,
    UserRegistrationDelete = 13,
    UserRegistrationVerified = 14,
    UserEmailVerified = 15,
    Test = 16
}
/**
 * @author Brian Pontarelli
 */
export declare enum ExpiryUnit {
    MINUTES = 0,
    HOURS = 1,
    DAYS = 2,
    WEEKS = 3,
    MONTHS = 4,
    YEARS = 5
}
/**
 * @author Daniel DeGroff
 */
export interface ExternalIdentifierConfiguration {
    authorizationGrantIdTimeToLiveInSeconds?: number;
    changePasswordIdGenerator?: SecureGeneratorConfiguration;
    changePasswordIdTimeToLiveInSeconds?: number;
    emailVerificationIdGenerator?: SecureGeneratorConfiguration;
    emailVerificationIdTimeToLiveInSeconds?: number;
    oneTimePasswordTimeToLiveInSeconds?: number;
    passwordlessLoginGenerator?: SecureGeneratorConfiguration;
    passwordlessLoginTimeToLiveInSeconds?: number;
    registrationVerificationIdGenerator?: SecureGeneratorConfiguration;
    registrationVerificationIdTimeToLiveInSeconds?: number;
    setupPasswordIdGenerator?: SecureGeneratorConfiguration;
    setupPasswordIdTimeToLiveInSeconds?: number;
    twoFactorIdTimeToLiveInSeconds?: number;
    twoFactorTrustIdTimeToLiveInSeconds?: number;
}
/**
 * @author Daniel DeGroff
 */
export interface ExternalJWTApplicationConfiguration extends BaseIdentityProviderApplicationConfiguration {
}
/**
 * External JWT-only identity provider.
 *
 * @author Daniel DeGroff and Brian Pontarelli
 */
export interface ExternalJWTIdentityProvider extends BaseIdentityProvider<ExternalJWTApplicationConfiguration> {
    claimMap?: Map<string, string>;
    domains?: Set<string>;
    headerKeyParameter?: string;
    keys?: Map<string, string>;
    oauth2?: IdentityProviderOauth2Configuration;
    type?: IdentityProviderType;
    uniqueIdentityClaim?: string;
}
/**
 * @author Daniel DeGroff
 */
export interface FacebookApplicationConfiguration extends BaseIdentityProviderApplicationConfiguration {
    appId?: string;
    buttonText?: string;
    client_secret?: string;
    fields?: string;
    permissions?: string;
}
/**
 * Facebook social login provider.
 *
 * @author Brian Pontarelli
 */
export interface FacebookIdentityProvider extends BaseIdentityProvider<FacebookApplicationConfiguration> {
    appId?: string;
    buttonText?: string;
    client_secret?: string;
    fields?: string;
    permissions?: string;
    type?: IdentityProviderType;
}
/**
 * Configuration for the behavior of failed login attempts. This helps us protect against brute force password attacks.
 *
 * @author Daniel DeGroff
 */
export interface FailedAuthenticationConfiguration {
    actionDuration?: number;
    actionDurationUnit?: ExpiryUnit;
    resetCountInSeconds?: number;
    tooManyAttempts?: number;
    userActionId?: string;
}
/**
 * Models a family grouping of users.
 *
 * @author Brian Pontarelli
 */
export interface Family {
    id?: string;
    members?: Array<FamilyMember>;
}
/**
 * @author Brian Pontarelli
 */
export interface FamilyConfiguration extends Enableable {
    allowChildRegistrations?: boolean;
    confirmChildEmailTemplateId?: string;
    deleteOrphanedAccounts?: boolean;
    deleteOrphanedAccountsDays?: number;
    familyRequestEmailTemplateId?: string;
    maximumChildAge?: number;
    minimumOwnerAge?: number;
    parentEmailRequired?: boolean;
    parentRegistrationEmailTemplateId?: string;
}
export interface FamilyConfiguration extends Enableable {
    allowChildRegistrations?: boolean;
    confirmChildEmailTemplateId?: string;
    deleteOrphanedAccounts?: boolean;
    deleteOrphanedAccountsDays?: number;
    familyRequestEmailTemplateId?: string;
    maximumChildAge?: number;
    minimumOwnerAge?: number;
    parentEmailRequired?: boolean;
    parentRegistrationEmailTemplateId?: string;
}
/**
 * API request for sending out family requests to parent's.
 *
 * @author Brian Pontarelli
 */
export interface FamilyEmailRequest {
    parentEmail?: string;
}
/**
 * Models a single family member.
 *
 * @author Brian Pontarelli
 */
export interface FamilyMember {
    data?: Map<string, any>;
    insertInstant?: number;
    owner?: boolean;
    role?: FamilyRole;
    userId?: string;
}
/**
 * API request for managing families and members.
 *
 * @author Brian Pontarelli
 */
export interface FamilyRequest {
    familyMember?: FamilyMember;
}
/**
 * API response for managing families and members.
 *
 * @author Brian Pontarelli
 */
export interface FamilyResponse {
    families?: Array<Family>;
    family?: Family;
}
export declare enum FamilyRole {
    Child = 0,
    Teen = 1,
    Adult = 2
}
/**
 * Forgot password request object.
 *
 * @author Brian Pontarelli
 */
export interface ForgotPasswordRequest {
    changePasswordId?: string;
    email?: string;
    loginId?: string;
    sendForgotPasswordEmail?: boolean;
    state?: Map<string, any>;
    username?: string;
}
/**
 * Forgot password response object.
 *
 * @author Daniel DeGroff
 */
export interface ForgotPasswordResponse {
    changePasswordId?: string;
}
/**
 * @author Daniel DeGroff
 */
export interface GoogleApplicationConfiguration extends BaseIdentityProviderApplicationConfiguration {
    buttonText?: string;
    client_id?: string;
    client_secret?: string;
    scope?: string;
}
/**
 * Google social login provider.
 *
 * @author Daniel DeGroff
 */
export interface GoogleIdentityProvider extends BaseIdentityProvider<GoogleApplicationConfiguration> {
    buttonText?: string;
    client_id?: string;
    client_secret?: string;
    scope?: string;
    type?: IdentityProviderType;
}
/**
 * Authorization Grant types as defined by the <a href="https://tools.ietf.org/html/rfc6749">The OAuth 2.0 Authorization
 * Framework - RFC 6749</a>.
 * <p>
 * Specific names as defined by <a href="https://tools.ietf.org/html/rfc7591#section-4.1">
 * OAuth 2.0 Dynamic Client Registration Protocol - RFC 7591 Section 4.1</a>
 *
 * @author Daniel DeGroff
 */
export declare enum GrantType {
    authorization_code = 0,
    implicit = 1,
    password = 2,
    client_credentials = 3,
    refresh_token = 4,
    unknown = 5
}
/**
 * @author Tyler Scott
 */
export interface Group {
    data?: Map<string, any>;
    id?: string;
    name?: string;
    roles?: Map<string, Array<ApplicationRole>>;
    tenantId?: string;
}
/**
 * A User's membership into a Group
 *
 * @author Daniel DeGroff
 */
export interface GroupMember {
    data?: Map<string, any>;
    groupId?: string;
    id?: string;
    insertInstant?: number;
    userId?: string;
}
/**
 * Group API request object.
 *
 * @author Daniel DeGroff
 */
export interface GroupRequest {
    group?: Group;
    roleIds?: Array<string>;
}
/**
 * Group API response object.
 *
 * @author Daniel DeGroff
 */
export interface GroupResponse {
    group?: Group;
    groups?: Array<Group>;
}
export interface HistoryItem {
    actionerUserId?: string;
    comment?: string;
    createInstant?: number;
    expiry?: number;
}
/**
 * Type for webhook headers.
 *
 * @author Brian Pontarelli
 */
export interface HTTPHeaders extends Map<string, string> {
}
export declare enum HTTPMethod {
    GET = 0,
    POST = 1,
    PUT = 2,
    DELETE = 3,
    HEAD = 4,
    OPTIONS = 5
}
/**
 * Login API request object used for login to third-party systems (i.e. Login with Facebook).
 *
 * @author Brian Pontarelli
 */
export interface IdentityProviderLoginRequest extends BaseLoginRequest {
    data?: Map<string, string>;
    encodedJWT?: string;
    identityProviderId?: string;
}
/**
 * @author Daniel DeGroff
 */
export interface IdentityProviderOauth2Configuration {
    authorization_endpoint?: string;
    client_id?: string;
    client_secret?: string;
    issuer?: string;
    scope?: string;
    token_endpoint?: string;
    userinfo_endpoint?: string;
}
/**
 * @author Daniel DeGroff
 */
export interface IdentityProviderRequest {
    identityProvider?: BaseIdentityProvider<any>;
}
/**
 * @author Daniel DeGroff
 */
export interface IdentityProviderResponse {
    identityProvider?: BaseIdentityProvider<any>;
    identityProviders?: Array<BaseIdentityProvider<any>>;
}
export declare enum IdentityProviderType {
    ExternalJWT = 0,
    OpenIDConnect = 1,
    Facebook = 2,
    Google = 3,
    Twitter = 4,
    SAMLv2 = 5
}
/**
 * Import request.
 *
 * @author Brian Pontarelli
 */
export interface ImportRequest {
    encryptionScheme?: string;
    factor?: number;
    users?: Array<User>;
    validateDbConstraints?: boolean;
}
/**
 * The Integration Request
 *
 * @author Daniel DeGroff
 */
export interface IntegrationRequest {
    integrations?: Integrations;
}
/**
 * The Integration Response
 *
 * @author Daniel DeGroff
 */
export interface IntegrationResponse {
    integrations?: Integrations;
}
/**
 * Available Integrations
 *
 * @author Daniel DeGroff
 */
export interface Integrations {
    cleanspeak?: CleanSpeakConfiguration;
    kafka?: KafkaConfiguration;
    twilio?: TwilioConfiguration;
}
/**
 * Counts for a period.
 *
 * @author Brian Pontarelli
 */
export interface IntervalCount {
    applicationId?: string;
    count?: number;
    decrementedCount?: number;
    period?: number;
}
/**
 * A user over an period (for daily and monthly active user calculations).
 *
 * @author Brian Pontarelli
 */
export interface IntervalUser {
    applicationId?: string;
    period?: number;
    userId?: string;
}
/**
 * @author Daniel DeGroff
 */
export interface IntrospectResponse extends Map<string, any> {
}
/**
 * @author Daniel DeGroff
 */
export interface IssueResponse {
    refreshToken?: string;
    token?: string;
}
/**
 * @author Daniel DeGroff
 */
export interface JWKSResponse {
    keys?: Array<object>;
}
/**
 * JWT Configuration. A JWT Configuration for an Application may not be active if it is using the global configuration, the configuration
 * may be <code>enabled = false</code>.
 *
 * @author Daniel DeGroff
 */
export interface JWTConfiguration extends Enableable {
    accessTokenKeyId?: string;
    idTokenKeyId?: string;
    refreshTokenTimeToLiveInMinutes?: number;
    timeToLiveInSeconds?: number;
}
/**
 * Models the JWT public key Refresh Token Revoke Event (and can be converted to JSON). This event might be for a single
 * token, a user or an entire application.
 *
 * @author Brian Pontarelli
 */
export interface JWTPublicKeyUpdateEvent extends BaseEvent {
    applicationIds?: Set<string>;
    type?: EventType;
}
/**
 * Models the Refresh Token Revoke Event (and can be converted to JSON). This event might be for a single token, a user
 * or an entire application.
 *
 * @author Brian Pontarelli
 */
export interface JWTRefreshTokenRevokeEvent extends BaseEvent {
    applicationId?: string;
    applicationTimeToLiveInSeconds?: Map<string, number>;
    type?: EventType;
    user?: User;
    userId?: string;
}
/**
 * @author Daniel DeGroff
 */
export interface KafkaConfiguration extends Enableable {
    defaultTopic?: string;
    producer?: Map<string, string>;
}
/**
 * Domain for a public key, key pair or an HMAC secret. This is used by KeyMaster to manage keys for JWTs, SAML, etc.
 *
 * @author Brian Pontarelli
 */
export interface Key {
    algorithm?: KeyAlgorithm;
    certificate?: string;
    certificateInformation?: CertificateInformation;
    displayName?: string;
    expirationInstant?: number;
    id?: string;
    insertInstant?: number;
    issuer?: string;
    kid?: string;
    length?: number;
    name?: string;
    pair?: boolean;
    privateKey?: string;
    publicKey?: string;
    secret?: string;
    type?: KeyType;
}
export declare enum KeyAlgorithm {
    ES256 = 0,
    ES384 = 1,
    ES512 = 2,
    HS256 = 3,
    HS384 = 4,
    HS512 = 5,
    RS256 = 6,
    RS384 = 7,
    RS512 = 8
}
/**
 * Key API request object.
 *
 * @author Daniel DeGroff
 */
export interface KeyRequest {
    key?: Key;
}
/**
 * Key API response object.
 *
 * @author Daniel DeGroff
 */
export interface KeyResponse {
    key?: Key;
    keys?: Array<Key>;
}
export declare enum KeyType {
    EC = 0,
    RSA = 1,
    HMAC = 2
}
/**
 * A JavaScript lambda function that is executed during certain events inside FusionAuth.
 *
 * @author Brian Pontarelli
 */
export interface Lambda extends Enableable {
    body?: string;
    debug?: boolean;
    id?: string;
    insertInstant?: number;
    name?: string;
    type?: LambdaType;
}
export interface LambdaConfiguration {
    accessTokenPopulateId?: string;
    idTokenPopulateId?: string;
    samlv2PopulateId?: string;
}
export interface LambdaConfiguration {
    reconcileId?: string;
}
/**
 * Lambda API request object.
 *
 * @author Brian Pontarelli
 */
export interface LambdaRequest {
    lambda?: Lambda;
}
/**
 * Lambda API response object.
 *
 * @author Brian Pontarelli
 */
export interface LambdaResponse {
    lambda?: Lambda;
    lambdas?: Array<Lambda>;
}
/**
 * The types of lambdas that indicate how they are invoked by FusionAuth.
 *
 * @author Brian Pontarelli
 */
export declare enum LambdaType {
    JWTPopulate = 0,
    OpenIDReconcile = 1,
    SAMLv2Reconcile = 2,
    SAMLv2Populate = 3
}
/**
 * Models a set of localized Integers that can be stored as JSON.
 *
 * @author Daniel DeGroff
 */
export interface LocalizedIntegers extends Map<string, number> {
}
/**
 * Models a set of localized Strings that can be stored as JSON.
 *
 * @author Brian Pontarelli
 */
export interface LocalizedStrings extends Map<string, string> {
}
/**
 * A historical state of a user log event. Since events can be modified, this stores the historical state.
 *
 * @author Brian Pontarelli
 */
export interface LogHistory {
    historyItems?: Array<HistoryItem>;
}
export interface LoginConfiguration {
    allowTokenRefresh?: boolean;
    generateRefreshTokens?: boolean;
    requireAuthentication?: boolean;
}
export declare enum LoginIdType {
    email = 0,
    username = 1
}
/**
 * The summary of the action that is preventing login to be returned on the login response.
 *
 * @author Daniel DeGroff
 */
export interface LoginPreventedResponse {
    actionerUserId?: string;
    actionId?: string;
    expiry?: number;
    localizedName?: string;
    localizedOption?: string;
    localizedReason?: string;
    name?: string;
    option?: string;
    reason?: string;
    reasonCode?: string;
}
export interface LoginRecordConfiguration {
    delete?: DeleteConfiguration;
}
/**
 * @author Daniel DeGroff
 */
export interface LoginRecordExportRequest extends BaseExportRequest {
    criteria?: LoginRecordSearchCriteria;
}
/**
 * @author Daniel DeGroff
 */
export interface LoginRecordSearchCriteria extends BaseSearchCriteria {
    applicationId?: string;
    end?: number;
    start?: number;
    userId?: string;
}
/**
 * @author Daniel DeGroff
 */
export interface LoginRecordSearchRequest {
    retrieveTotal?: boolean;
    search?: LoginRecordSearchCriteria;
}
/**
 * A raw login record response
 *
 * @author Daniel DeGroff
 */
export interface LoginRecordSearchResponse {
    logins?: Array<DisplayableRawLogin>;
    total?: number;
}
/**
 * Response for the login report.
 *
 * @author Brian Pontarelli
 */
export interface LoginReportResponse {
    hourlyCounts?: Array<Count>;
    total?: number;
}
/**
 * Login API request object.
 *
 * @author Seth Musselman
 */
export interface LoginRequest extends BaseLoginRequest {
    loginId?: string;
    oneTimePassword?: string;
    password?: string;
    twoFactorTrustId?: string;
}
/**
 * @author Brian Pontarelli
 */
export interface LoginResponse {
    actions?: Array<LoginPreventedResponse>;
    changePasswordId?: string;
    refreshToken?: string;
    state?: Map<string, any>;
    token?: string;
    twoFactorId?: string;
    twoFactorTrustId?: string;
    user?: User;
}
/**
 * @author Daniel DeGroff
 */
export interface LookupResponse {
    identityProvider?: BaseIdentityProvider<any>;
}
/**
 * @author Daniel DeGroff
 */
export interface MaximumPasswordAge extends Enableable {
    days?: number;
}
/**
 * Group Member Delete Request
 *
 * @author Daniel DeGroff
 */
export interface MemberDeleteRequest {
    memberIds?: Array<string>;
    members?: Map<string, Array<string>>;
}
/**
 * Group Member Request
 *
 * @author Daniel DeGroff
 */
export interface MemberRequest {
    members?: Map<string, Array<GroupMember>>;
}
/**
 * Group Member Response
 *
 * @author Daniel DeGroff
 */
export interface MemberResponse {
    members?: Map<string, Array<GroupMember>>;
}
export interface MetaData {
    device?: DeviceInfo;
    scopes?: Set<string>;
}
/**
 * @author Daniel DeGroff
 */
export interface MinimumPasswordAge extends Enableable {
    seconds?: number;
}
/**
 * Response for the daily active user report.
 *
 * @author Brian Pontarelli
 */
export interface MonthlyActiveUserReportResponse {
    monthlyActiveUsers?: Array<Count>;
    total?: number;
}
/**
 * Helper methods for normalizing values.
 *
 * @author Brian Pontarelli
 */
export interface Normalizer {
}
/**
 * @author Daniel DeGroff
 */
export interface OAuth2Configuration {
    authorizedOriginURLs?: Array<string>;
    authorizedRedirectURLs?: Array<string>;
    clientId?: string;
    clientSecret?: string;
    enabledGrants?: Set<GrantType>;
    generateRefreshTokens?: boolean;
    logoutURL?: string;
    requireClientAuthentication?: boolean;
}
/**
 * @author Daniel DeGroff
 */
export interface OAuthConfigurationResponse {
    httpSessionMaxInactiveInterval?: number;
    logoutURL?: string;
    oauthConfiguration?: OAuth2Configuration;
}
/**
 * @author Daniel DeGroff
 */
export interface OAuthError {
    change_password_id?: string;
    error?: OAuthErrorType;
    error_description?: string;
    error_reason?: OAuthErrorReason;
    error_uri?: string;
    two_factor_id?: string;
}
export declare enum OAuthErrorReason {
    auth_code_not_found = 0,
    access_token_malformed = 1,
    access_token_expired = 2,
    access_token_unavailable_for_processing = 3,
    access_token_failed_processing = 4,
    refresh_token_not_found = 5,
    invalid_client_id = 6,
    invalid_user_credentials = 7,
    invalid_grant_type = 8,
    invalid_origin = 9,
    invalid_pkce_code_verifier = 10,
    invalid_pkce_code_challenge = 11,
    invalid_pkce_code_challenge_method = 12,
    invalid_redirect_uri = 13,
    invalid_response_type = 14,
    invalid_id_token_hint = 15,
    invalid_post_logout_redirect_uri = 16,
    grant_type_disabled = 17,
    missing_client_id = 18,
    missing_code = 19,
    missing_grant_type = 20,
    missing_redirect_uri = 21,
    missing_refresh_token = 22,
    missing_response_type = 23,
    missing_token = 24,
    login_prevented = 25,
    user_expired = 26,
    user_locked = 27,
    user_not_found = 28,
    client_authentication_missing = 29,
    invalid_client_authentication_scheme = 30,
    invalid_client_authentication = 31,
    client_id_mismatch = 32,
    unknown = 33
}
export declare enum OAuthErrorType {
    invalid_request = 0,
    invalid_client = 1,
    invalid_grant = 2,
    invalid_token = 3,
    unauthorized_client = 4,
    invalid_scope = 5,
    server_error = 6,
    unsupported_grant_type = 7,
    unsupported_response_type = 8,
    change_password_required = 9,
    two_factor_required = 10
}
/**
 * @author Daniel DeGroff
 */
export interface OAuthResponse {
}
/**
 * OpenID Configuration as described by the <a href="https://openid.net/specs/openid-connect-discovery-1_0.html#ProviderMetadata">OpenID
 * Provider Metadata</a>.
 *
 * @author Daniel DeGroff
 */
export interface OpenIdConfiguration {
    authorization_endpoint?: string;
    backchannel_logout_supported?: boolean;
    claims_supported?: Array<string>;
    end_session_endpoint?: string;
    frontchannel_logout_supported?: boolean;
    grant_types_supported?: Array<string>;
    id_token_signing_alg_values_supported?: Array<string>;
    issuer?: string;
    jwks_uri?: string;
    response_types_supported?: Array<string>;
    scopes_supported?: Array<string>;
    subject_types_supported?: Array<string>;
    token_endpoint?: string;
    token_endpoint_auth_methods_supported?: Array<string>;
    userinfo_endpoint?: string;
    userinfo_signing_alg_values_supported?: Array<string>;
}
/**
 * @author Daniel DeGroff
 */
export interface OpenIdConnectApplicationConfiguration extends BaseIdentityProviderApplicationConfiguration {
    buttonImageURL?: string;
    buttonText?: string;
    oauth2?: IdentityProviderOauth2Configuration;
}
/**
 * @author Daniel DeGroff
 */
export interface OpenIdConnectIdentityProvider extends BaseIdentityProvider<OpenIdConnectApplicationConfiguration> {
    buttonImageURL?: string;
    buttonText?: string;
    domains?: Set<string>;
    lambdaConfiguration?: LambdaConfiguration;
    oauth2?: IdentityProviderOauth2Configuration;
    type?: IdentityProviderType;
}
/**
 * Password Encryption Scheme Configuration
 *
 * @author Daniel DeGroff
 */
export interface PasswordEncryptionConfiguration {
    encryptionScheme?: string;
    encryptionSchemeFactor?: number;
    modifyEncryptionSchemeOnLogin?: boolean;
}
export interface PasswordlessConfiguration extends Enableable {
}
/**
 * @author Daniel DeGroff
 */
export interface PasswordlessLoginRequest extends BaseLoginRequest {
    code?: string;
    twoFactorTrustId?: string;
}
/**
 * @author Daniel DeGroff
 */
export interface PasswordlessSendRequest {
    applicationId?: string;
    loginId?: string;
    state?: Map<string, any>;
}
/**
 * @author Derek Klatt
 */
export interface PasswordValidationRules {
    maxLength?: number;
    minLength?: number;
    rememberPreviousPasswords?: RememberPreviousPasswords;
    requireMixedCase?: boolean;
    requireNonAlpha?: boolean;
    requireNumber?: boolean;
}
/**
 * @author Daniel DeGroff
 */
export interface PasswordValidationRulesResponse {
    passwordValidationRules?: PasswordValidationRules;
}
/**
 * @author Brian Pontarelli
 */
export interface PendingResponse {
    users?: Array<User>;
}
/**
 * @author Brian Pontarelli
 */
export interface PreviewRequest {
    emailTemplate?: EmailTemplate;
    locale?: string;
}
/**
 * @author Seth Musselman
 */
export interface PreviewResponse {
    email?: Email;
    errors?: Errors;
}
/**
 * JWT Public Key Response Object
 *
 * @author Daniel DeGroff
 */
export interface PublicKeyResponse {
    publicKey?: string;
    publicKeys?: Map<string, string>;
}
/**
 * Raw login information for each time a user logs into an application.
 *
 * @author Brian Pontarelli
 */
export interface RawLogin {
    applicationId?: string;
    instant?: number;
    ipAddress?: string;
    userId?: string;
}
/**
 * Response for the user login report.
 *
 * @author Seth Musselman
 */
export interface RecentLoginResponse {
    logins?: Array<DisplayableRawLogin>;
}
/**
 * @author Daniel DeGroff
 */
export interface RefreshRequest {
    refreshToken?: string;
}
/**
 * @author Daniel DeGroff
 */
export interface RefreshResponse {
    refreshTokens?: Array<RefreshToken>;
    token?: string;
}
/**
 * Models a JWT Refresh Token.
 *
 * @author Daniel DeGroff
 */
export interface RefreshToken {
    application?: Application;
    applicationId?: string;
    insertInstant?: number;
    metaData?: MetaData;
    startInstant?: number;
    token?: string;
    userId?: string;
}
export interface RegistrationConfiguration extends Enableable {
    birthDate?: Requirable;
    confirmPassword?: boolean;
    firstName?: Requirable;
    fullName?: Requirable;
    lastName?: Requirable;
    loginIdType?: LoginIdType;
    middleName?: Requirable;
    mobilePhone?: Requirable;
}
/**
 * Response for the registration report.
 *
 * @author Brian Pontarelli
 */
export interface RegistrationReportResponse {
    hourlyCounts?: Array<Count>;
    total?: number;
}
/**
 * Registration API request object.
 *
 * @author Brian Pontarelli
 */
export interface RegistrationRequest {
    generateAuthenticationToken?: boolean;
    registration?: UserRegistration;
    sendSetPasswordEmail?: boolean;
    skipRegistrationVerification?: boolean;
    skipVerification?: boolean;
    user?: User;
}
/**
 * Registration API request object.
 *
 * @author Brian Pontarelli
 */
export interface RegistrationResponse {
    registration?: UserRegistration;
    user?: User;
}
/**
 * @author Daniel DeGroff
 */
export interface ReloadRequest {
    names?: Array<string>;
}
/**
 * @author Daniel DeGroff
 */
export interface RememberPreviousPasswords extends Enableable {
    count?: number;
}
/**
 * Something that can be required and thus also optional. This currently extends Enableable because anything that is
 * require/optional is almost always enableable as well.
 *
 * @author Brian Pontarelli
 */
export interface Requirable extends Enableable {
    required?: boolean;
}
/**
 * @author Brian Pontarelli
 */
export interface SAML2ApplicationConfiguration extends BaseIdentityProviderApplicationConfiguration {
    buttonImageURL?: string;
    buttonText?: string;
}
/**
 * SAML v2 identity provider configuration.
 *
 * @author Brian Pontarelli
 */
export interface SAML2IdentityProvider extends BaseIdentityProvider<SAML2ApplicationConfiguration> {
    buttonImageURL?: string;
    buttonText?: string;
    claimMap?: Map<string, string>;
    domains?: Set<string>;
    emailClaim?: string;
    idpEndpoint?: string;
    requestPrivateKey?: string;
    requestPublicKey?: string;
    responsePublicKey?: string;
    rolesClaim?: string;
    type?: IdentityProviderType;
}
/**
 * @author Brian Pontarelli
 */
export interface SAMLv2ApplicationConfiguration extends BaseIdentityProviderApplicationConfiguration {
    buttonImageURL?: string;
    buttonText?: string;
}
export interface SAMLv2Configuration extends Enableable {
    audience?: string;
    callbackURL?: string;
    debug?: boolean;
    issuer?: string;
    keyId?: string;
    logoutURL?: string;
    xmlSignatureC14nMethod?: CanonicalizationMethod;
}
/**
 * SAML v2 identity provider configuration.
 *
 * @author Brian Pontarelli
 */
export interface SAMLv2IdentityProvider extends BaseIdentityProvider<SAMLv2ApplicationConfiguration> {
    buttonImageURL?: string;
    buttonText?: string;
    domains?: Set<string>;
    emailClaim?: string;
    idpEndpoint?: string;
    issuer?: string;
    keyId?: string;
    lambdaConfiguration?: LambdaConfiguration;
    type?: IdentityProviderType;
    useNameIdForEmail?: boolean;
}
/**
 * Search API request.
 *
 * @author Brian Pontarelli
 */
export interface SearchRequest {
    search?: UserSearchCriteria;
}
/**
 * Search API response.
 *
 * @author Brian Pontarelli
 */
export interface SearchResponse {
    total?: number;
    users?: Array<User>;
}
/**
 * Search results.
 *
 * @author Brian Pontarelli
 */
export interface SearchResults<T> {
    results?: Array<T>;
    total?: number;
}
/**
 * @author Daniel DeGroff
 */
export interface SecretResponse {
    secret?: string;
    secretBase32Encoded?: string;
}
/**
 * @author Daniel DeGroff
 */
export interface SecureGeneratorConfiguration {
    length?: number;
    type?: SecureGeneratorType;
}
/**
 * @author Daniel DeGroff
 */
export declare enum SecureGeneratorType {
    randomDigits = 0,
    randomBytes = 1
}
/**
 * @author Daniel DeGroff
 */
export interface SecureIdentity {
    encryptionScheme?: string;
    factor?: number;
    id?: string;
    password?: string;
    passwordChangeRequired?: boolean;
    passwordLastUpdateInstant?: number;
    salt?: string;
    verified?: boolean;
}
/**
 * @author Daniel DeGroff
 */
export interface SendRequest {
    bccAddresses?: Array<string>;
    ccAddresses?: Array<string>;
    requestData?: Map<string, any>;
    userIds?: Array<string>;
}
/**
 * @author Daniel DeGroff
 */
export interface SendResponse {
    results?: Map<string, EmailTemplateErrors>;
}
/**
 * @author Daniel DeGroff
 */
export declare enum Sort {
    asc = 0,
    desc = 1
}
/**
 * @author Daniel DeGroff
 */
export interface SortField {
    missing?: string;
    name?: string;
    order?: Sort;
}
/**
 * @author Brian Pontarelli
 */
export interface SystemConfiguration {
    auditLogConfiguration?: AuditLogConfiguration;
    cookieEncryptionIV?: string;
    cookieEncryptionKey?: string;
    corsConfiguration?: CORSConfiguration;
    data?: Map<string, any>;
    eventLogConfiguration?: EventLogConfiguration;
    loginRecordConfiguration?: LoginRecordConfiguration;
    reportTimezone?: string;
    uiConfiguration?: UIConfiguration;
}
/**
 * Request for the system configuration API.
 *
 * @author Brian Pontarelli
 */
export interface SystemConfigurationRequest {
    systemConfiguration?: SystemConfiguration;
}
/**
 * Response for the system configuration API.
 *
 * @author Brian Pontarelli
 */
export interface SystemConfigurationResponse {
    systemConfiguration?: SystemConfiguration;
}
export interface Templates {
    emailComplete?: string;
    emailSend?: string;
    emailVerify?: string;
    helpers?: string;
    oauth2Authorize?: string;
    oauth2ChildRegistrationNotAllowed?: string;
    oauth2ChildRegistrationNotAllowedComplete?: string;
    oauth2CompleteRegistration?: string;
    oauth2Error?: string;
    oauth2Logout?: string;
    oauth2Passwordless?: string;
    oauth2Register?: string;
    oauth2TwoFactor?: string;
    passwordChange?: string;
    passwordComplete?: string;
    passwordForgot?: string;
    passwordSent?: string;
    registrationComplete?: string;
    registrationSend?: string;
    registrationVerify?: string;
}
/**
 * @author Daniel DeGroff
 */
export interface Tenant {
    configured?: boolean;
    data?: Map<string, any>;
    emailConfiguration?: EmailConfiguration;
    eventConfiguration?: EventConfiguration;
    externalIdentifierConfiguration?: ExternalIdentifierConfiguration;
    failedAuthenticationConfiguration?: FailedAuthenticationConfiguration;
    familyConfiguration?: FamilyConfiguration;
    httpSessionMaxInactiveInterval?: number;
    id?: string;
    issuer?: string;
    jwtConfiguration?: JWTConfiguration;
    logoutURL?: string;
    maximumPasswordAge?: MaximumPasswordAge;
    minimumPasswordAge?: MinimumPasswordAge;
    name?: string;
    passwordEncryptionConfiguration?: PasswordEncryptionConfiguration;
    passwordValidationRules?: PasswordValidationRules;
    themeId?: string;
}
/**
 * @author Brian Pontarelli
 */
export interface Tenantable {
}
export interface TenantEmailConfiguration extends Enableable {
    forgotPasswordEmailTemplateId?: string;
    passwordlessEmailTemplateId?: string;
    setPasswordEmailTemplateId?: string;
    verificationEmailTemplateId?: string;
    verifyEmail?: boolean;
    verifyEmailWhenChanged?: boolean;
}
/**
 * @author Daniel DeGroff
 */
export interface TenantRequest {
    tenant?: Tenant;
}
/**
 * @author Daniel DeGroff
 */
export interface TenantResponse {
    tenant?: Tenant;
    tenants?: Array<Tenant>;
}
/**
 * @author Daniel DeGroff
 */
export interface TestEvent extends BaseEvent {
    message?: string;
    type?: EventType;
}
/**
 * @author Trevor Smith
 */
export interface Theme {
    data?: Map<string, any>;
    defaultMessages?: string;
    id?: string;
    insertInstant?: number;
    lastUpdateInstant?: number;
    localizedMessages?: LocalizedStrings;
    name?: string;
    stylesheet?: string;
    templates?: Templates;
}
/**
 * Theme API request object.
 *
 * @author Trevor Smith
 */
export interface ThemeRequest {
    sourceThemeId?: string;
    theme?: Theme;
}
/**
 * Theme API response object.
 *
 * @author Trevor Smith
 */
export interface ThemeResponse {
    theme?: Theme;
    themes?: Array<Theme>;
}
/**
 * <ul>
 * <li>Bearer Token type as defined by <a href="https://tools.ietf.org/html/rfc6750">RFC 6750</a>.</li>
 * <li>MAC Token type as referenced by <a href="https://tools.ietf.org/html/rfc6749">RFC 6749</a> and
 * <a href="https://tools.ietf.org/html/draft-ietf-oauth-v2-http-mac-05">
 * Draft RFC on OAuth 2.0 Message Authentication Code (MAC) Tokens</a>
 * </li>
 * </ul>
 *
 * @author Daniel DeGroff
 */
export declare enum TokenType {
    Bearer = 0,
    MAC = 1
}
export interface Totals {
    logins?: number;
    registrations?: number;
    totalRegistrations?: number;
}
/**
 * The response from the total report. This report stores the total numbers for each application.
 *
 * @author Brian Pontarelli
 */
export interface TotalsReportResponse {
    applicationTotals?: Map<string, Totals>;
    globalRegistrations?: number;
    totalGlobalRegistrations?: number;
}
/**
 * The transaction types for Webhooks and other event systems within FusionAuth.
 *
 * @author Brian Pontarelli
 */
export declare enum TransactionType {
    None = 0,
    Any = 1,
    SimpleMajority = 2,
    SuperMajority = 3,
    AbsoluteMajority = 4
}
/**
 * Twilio Service Configuration.
 *
 * @author Daniel DeGroff
 */
export interface TwilioConfiguration extends Enableable {
    accountSID?: string;
    authToken?: string;
    fromPhoneNumber?: string;
    messagingServiceSid?: string;
    url?: string;
}
/**
 * @author Daniel DeGroff
 */
export interface TwitterApplicationConfiguration extends BaseIdentityProviderApplicationConfiguration {
    buttonText?: string;
    consumerKey?: string;
    consumerSecret?: string;
}
/**
 * Twitter social login provider.
 *
 * @author Daniel DeGroff
 */
export interface TwitterIdentityProvider extends BaseIdentityProvider<TwitterApplicationConfiguration> {
    buttonText?: string;
    consumerKey?: string;
    consumerSecret?: string;
    type?: IdentityProviderType;
}
/**
 * @author Daniel DeGroff
 */
export declare enum TwoFactorDelivery {
    None = 0,
    TextMessage = 1
}
/**
 * @author Daniel DeGroff
 */
export interface TwoFactorLoginRequest extends BaseLoginRequest {
    code?: string;
    trustComputer?: boolean;
    twoFactorId?: string;
}
/**
 * @author Brian Pontarelli
 */
export interface TwoFactorRequest {
    code?: string;
    delivery?: TwoFactorDelivery;
    secret?: string;
    secretBase32Encoded?: string;
}
/**
 * @author Daniel DeGroff
 */
export interface TwoFactorSendRequest {
    mobilePhone?: string;
    secret?: string;
    userId?: string;
}
export interface UIConfiguration {
    headerColor?: string;
    logoURL?: string;
    menuFontColor?: string;
}
/**
 * The global view of a User. This object contains all global information about the user including birth date, registration information
 * preferred languages, global attributes, etc.
 *
 * @author Seth Musselman
 */
export interface User extends SecureIdentity {
    active?: boolean;
    age?: number;
    birthDate?: string;
    cleanSpeakId?: string;
    data?: Map<string, any>;
    email?: string;
    expiry?: number;
    firstName?: string;
    fullName?: string;
    imageUrl?: string;
    insertInstant?: number;
    lastLoginInstant?: number;
    lastName?: string;
    login?: string;
    memberships?: Array<GroupMember>;
    middleName?: string;
    mobilePhone?: string;
    name?: string;
    parentEmail?: string;
    preferredLanguages?: Array<string>;
    registrations?: Array<UserRegistration>;
    tenantId?: string;
    timezone?: string;
    twoFactorDelivery?: TwoFactorDelivery;
    twoFactorEnabled?: boolean;
    twoFactorSecret?: string;
    username?: string;
    usernameStatus?: ContentStatus;
}
/**
 * An action that can be executed on a user (discipline or reward potentially).
 *
 * @author Brian Pontarelli
 */
export interface UserAction {
    active?: boolean;
    cancelEmailTemplateId?: string;
    endEmailTemplateId?: string;
    id?: string;
    includeEmailInEventJSON?: boolean;
    localizedNames?: LocalizedStrings;
    modifyEmailTemplateId?: string;
    name?: string;
    options?: Array<UserActionOption>;
    preventLogin?: boolean;
    sendEndEvent?: boolean;
    startEmailTemplateId?: string;
    temporal?: boolean;
    transactionType?: TransactionType;
    userEmailingEnabled?: boolean;
    userNotificationsEnabled?: boolean;
}
/**
 * Models the user action event (and can be converted to JSON).
 *
 * @author Brian Pontarelli
 */
export interface UserActionEvent extends BaseEvent {
    action?: string;
    actioneeUserId?: string;
    actionerUserId?: string;
    actionId?: string;
    applicationIds?: Array<string>;
    comment?: string;
    email?: Email;
    emailedUser?: boolean;
    expiry?: number;
    localizedAction?: string;
    localizedDuration?: string;
    localizedOption?: string;
    localizedReason?: string;
    notifyUser?: boolean;
    option?: string;
    phase?: UserActionPhase;
    reason?: string;
    reasonCode?: string;
    type?: EventType;
}
/**
 * A log for an action that was taken on a User.
 *
 * @author Brian Pontarelli
 */
export interface UserActionLog {
    actioneeUserId?: string;
    actionerUserId?: string;
    applicationIds?: Array<string>;
    comment?: string;
    createInstant?: number;
    emailUserOnEnd?: boolean;
    endEventSent?: boolean;
    expiry?: number;
    history?: LogHistory;
    id?: string;
    localizedName?: string;
    localizedOption?: string;
    localizedReason?: string;
    name?: string;
    notifyUserOnEnd?: boolean;
    option?: string;
    reason?: string;
    reasonCode?: string;
    userActionId?: string;
}
/**
 * Models content user action options.
 *
 * @author Brian Pontarelli
 */
export interface UserActionOption {
    localizedNames?: LocalizedStrings;
    name?: string;
}
/**
 * The phases of a time-based user action.
 *
 * @author Brian Pontarelli
 */
export declare enum UserActionPhase {
    start = 0,
    modify = 1,
    cancel = 2,
    end = 3
}
/**
 * Models action reasons.
 *
 * @author Brian Pontarelli
 */
export interface UserActionReason {
    code?: string;
    id?: string;
    localizedTexts?: LocalizedStrings;
    text?: string;
}
/**
 * User Action Reason API request object.
 *
 * @author Brian Pontarelli
 */
export interface UserActionReasonRequest {
    userActionReason?: UserActionReason;
}
/**
 * User Action Reason API response object.
 *
 * @author Brian Pontarelli
 */
export interface UserActionReasonResponse {
    userActionReason?: UserActionReason;
    userActionReasons?: Array<UserActionReason>;
}
/**
 * User Action API request object.
 *
 * @author Brian Pontarelli
 */
export interface UserActionRequest {
    userAction?: UserAction;
}
/**
 * User Action API response object.
 *
 * @author Brian Pontarelli
 */
export interface UserActionResponse {
    userAction?: UserAction;
    userActions?: Array<UserAction>;
}
/**
 * Models the User Bulk Create Event (and can be converted to JSON).
 *
 * @author Brian Pontarelli
 */
export interface UserBulkCreateEvent extends BaseEvent {
    type?: EventType;
    users?: Array<User>;
}
/**
 * A log for an event that happened to a User.
 *
 * @author Brian Pontarelli
 */
export interface UserComment {
    comment?: string;
    commenterId?: string;
    createInstant?: number;
    id?: string;
    userId?: string;
}
/**
 * @author Seth Musselman
 */
export interface UserCommentRequest {
    userComment?: UserComment;
}
/**
 * User Comment Response
 *
 * @author Seth Musselman
 */
export interface UserCommentResponse {
    userComment?: UserComment;
    userComments?: Array<UserComment>;
}
/**
 * Models a User consent.
 *
 * @author Daniel DeGroff
 */
export interface UserConsent {
    consent?: Consent;
    consentId?: string;
    data?: Map<string, any>;
    giverUserId?: string;
    id?: string;
    insertInstant?: number;
    lastUpdateInstant?: number;
    status?: ConsentStatus;
    userId?: string;
    values?: Array<string>;
}
/**
 * API response for User consent.
 *
 * @author Daniel DeGroff
 */
export interface UserConsentRequest {
    userConsent?: UserConsent;
}
/**
 * API response for User consent.
 *
 * @author Daniel DeGroff
 */
export interface UserConsentResponse {
    userConsent?: UserConsent;
    userConsents?: Array<UserConsent>;
}
/**
 * Models the User Create Event (and can be converted to JSON).
 *
 * @author Brian Pontarelli
 */
export interface UserCreateEvent extends BaseEvent {
    type?: EventType;
    user?: User;
}
/**
 * Models the User Deactivate Event (and can be converted to JSON).
 *
 * @author Brian Pontarelli
 */
export interface UserDeactivateEvent extends BaseEvent {
    type?: EventType;
    user?: User;
}
/**
 * Models the User Event (and can be converted to JSON) that is used for all user modifications (create, update,
 * delete).
 *
 * @author Brian Pontarelli
 */
export interface UserDeleteEvent extends BaseEvent {
    type?: EventType;
    user?: User;
}
/**
 * User API delete request object.
 *
 * @author Daniel DeGroff
 */
export interface UserDeleteRequest {
    hardDelete?: boolean;
    userIds?: Array<string>;
}
/**
 * Models the User Email Verify Event (and can be converted to JSON).
 *
 * @author Trevor Smith
 */
export interface UserEmailVerifiedEvent extends BaseEvent {
    type?: EventType;
    user?: User;
}
/**
 * @author Daniel DeGroff
 */
export interface UserinfoResponse extends Map<string, any> {
}
/**
 * Models the User Login Failed Event.
 *
 * @author Daniel DeGroff
 */
export interface UserLoginFailedEvent extends BaseEvent {
    applicationId?: string;
    authenticationType?: string;
    type?: EventType;
    user?: User;
}
/**
 * Models the User Login Success Event.
 *
 * @author Daniel DeGroff
 */
export interface UserLoginSuccessEvent extends BaseEvent {
    applicationId?: string;
    authenticationType?: string;
    identityProviderId?: string;
    identityProviderName?: string;
    type?: EventType;
    user?: User;
}
export interface UsernameModeration extends Enableable {
    applicationId?: string;
}
/**
 * Models the User Reactivate Event (and can be converted to JSON).
 *
 * @author Brian Pontarelli
 */
export interface UserReactivateEvent extends BaseEvent {
    type?: EventType;
    user?: User;
}
/**
 * User registration information for a single application.
 *
 * @author Brian Pontarelli
 */
export interface UserRegistration {
    applicationId?: string;
    authenticationToken?: string;
    cleanSpeakId?: string;
    data?: Map<string, any>;
    id?: string;
    insertInstant?: number;
    lastLoginInstant?: number;
    preferredLanguages?: Array<string>;
    roles?: Set<string>;
    timezone?: string;
    tokens?: Map<string, string>;
    username?: string;
    usernameStatus?: ContentStatus;
    verified?: boolean;
}
/**
 * Models the User Create Registration Event (and can be converted to JSON).
 *
 * @author Daniel DeGroff
 */
export interface UserRegistrationCreateEvent extends BaseEvent {
    applicationId?: string;
    registration?: UserRegistration;
    type?: EventType;
    user?: User;
}
/**
 * Models the User Delete Registration Event (and can be converted to JSON).
 *
 * @author Daniel DeGroff
 */
export interface UserRegistrationDeleteEvent extends BaseEvent {
    applicationId?: string;
    registration?: UserRegistration;
    type?: EventType;
    user?: User;
}
/**
 * Models the User Update Registration Event (and can be converted to JSON).
 *
 * @author Daniel DeGroff
 */
export interface UserRegistrationUpdateEvent extends BaseEvent {
    applicationId?: string;
    original?: UserRegistration;
    registration?: UserRegistration;
    type?: EventType;
    user?: User;
}
/**
 * Models the User Registration Verified Event (and can be converted to JSON).
 *
 * @author Trevor Smith
 */
export interface UserRegistrationVerifiedEvent extends BaseEvent {
    applicationId?: string;
    registration?: UserRegistration;
    type?: EventType;
    user?: User;
}
/**
 * User API request object.
 *
 * @author Brian Pontarelli
 */
export interface UserRequest {
    sendSetPasswordEmail?: boolean;
    skipVerification?: boolean;
    user?: User;
}
/**
 * User API response object.
 *
 * @author Brian Pontarelli
 */
export interface UserResponse {
    user?: User;
}
/**
 * This class is the user query. It provides a build pattern as well as public fields for use on forms and in actions.
 *
 * @author Brian Pontarelli
 */
export interface UserSearchCriteria extends BaseSearchCriteria {
    email?: string;
    fullName?: string;
    id?: string;
    ids?: Array<string>;
    queryString?: string;
    sortFields?: Array<SortField>;
    username?: string;
}
/**
 * @author Daniel DeGroff
 */
export declare enum UserState {
    Authenticated = 0,
    AuthenticatedNotRegistered = 1
}
/**
 * Models the User Update Event (and can be converted to JSON).
 *
 * @author Brian Pontarelli
 */
export interface UserUpdateEvent extends BaseEvent {
    original?: User;
    type?: EventType;
    user?: User;
}
/**
 * @author Daniel DeGroff
 */
export interface ValidateResponse {
    jwt?: object;
}
/**
 * @author Daniel DeGroff
 */
export interface VerifyEmailResponse {
    verificationId?: string;
}
/**
 * @author Daniel DeGroff
 */
export interface VerifyRegistrationResponse {
    verificationId?: string;
}
/**
 * A server where events are sent. This includes user action events and any other events sent by FusionAuth.
 *
 * @author Brian Pontarelli
 */
export interface Webhook {
    applicationIds?: Array<string>;
    connectTimeout?: number;
    data?: WebhookData;
    description?: string;
    global?: boolean;
    headers?: HTTPHeaders;
    httpAuthenticationPassword?: string;
    httpAuthenticationUsername?: string;
    id?: string;
    readTimeout?: number;
    sslCertificate?: string;
    url?: string;
}
export interface WebhookData {
    eventsEnabled?: Map<EventType, boolean>;
}
/**
 * Webhook API request object.
 *
 * @author Brian Pontarelli
 */
export interface WebhookRequest {
    webhook?: Webhook;
}
/**
 * Webhook API response object.
 *
 * @author Brian Pontarelli
 */
export interface WebhookResponse {
    webhook?: Webhook;
    webhooks?: Array<Webhook>;
}
